/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2011 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 5.3                   *
*********************************************************************************
* Id: mimetypedialog.cpp,                         2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "MimeTypeDialog.h"
#include "LanguageDialog.h"
#include "fxmoviemanager.h"
#include "icons.h"
#include "config.h"


FXDEFMAP(MimeTypeDialog) MimeTypeDialogMap[]={

  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_ICONPATH,		MimeTypeDialog::onCmdSelectIconPath),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_COMMAND,		MimeTypeDialog::onCmdSelectCommand),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_MIMETYPE,		MimeTypeDialog::onCmdSelectMimeType),
  FXMAPFUNC(SEL_CLOSE,	MimeTypeDialog::ID_FXMMAPPLICATION,		MimeTypeDialog::onCmdCloseDialog),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_CREATE_MIMEASSOCIATION,	MimeTypeDialog::onCmdCreateFileAssociation),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_DELETE_MIMEASSOCIATION,	MimeTypeDialog::onCmdDeleteFileAssociation),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_RENAME_MIMEASSOCIATION,	MimeTypeDialog::onCmdRenameFileAssociation),
  FXMAPFUNC(SEL_CHANGED,MimeTypeDialog::ID_SELECT_MIMEASSOCIATION,	MimeTypeDialog::onCmdFileAssociation),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_TERMINAL,		MimeTypeDialog::onCmdSelectTerminal),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_FONT,			MimeTypeDialog::onCmdSelectFont),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_SELECT_FONT2,		MimeTypeDialog::onCmdSelectFont2),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_RESTORE_SETTINGS,		MimeTypeDialog::onCmdRestoreDefaults),
  FXMAPFUNC(SEL_COMMAND,MimeTypeDialog::ID_CUSTOM_LANGUAGE,		MimeTypeDialog::onCmdCustomLanguage),
  FXMAPFUNCS(SEL_COMMAND,MimeTypeDialog::ID_SELECT_PLAYER_MPLAYER,	MimeTypeDialog::ID_SELECT_PLAYER_FXPLAYER,	MimeTypeDialog::onCmdSelectPlayer),
  FXMAPFUNCS(SEL_COMMAND,MimeTypeDialog::ID_SELECT_THEME_DARK,		MimeTypeDialog::ID_SELECT_THEME_SUN,		MimeTypeDialog::onCmdSelectThemeColors),
  FXMAPFUNCS(SEL_COMMAND,MimeTypeDialog::ID_SELECT_LANGUAGE_EN,		MimeTypeDialog::ID_SELECT_LANGUAGE_CU,		MimeTypeDialog::onCmdSelectLanguage),
  FXMAPFUNCS(SEL_COMMAND,MimeTypeDialog::ID_SELECT_ICONBIG_NAME,	MimeTypeDialog::ID_SELECT_ICONSMALL_NAME,	MimeTypeDialog::onCmdSelectIcon),
  };


// Object implementation
FXIMPLEMENT(MimeTypeDialog,FXDialogBox,MimeTypeDialogMap,ARRAYNUMBER(MimeTypeDialogMap))


// Construct window
MimeTypeDialog::MimeTypeDialog(FXWindow *own):FXDialogBox(own,"FXMovieManager Setup",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0){

  // Default font
  bodyfont=NULL;
  menufont=NULL;

  // get general Settings
  fxmmwheellines = getApp()->reg().readIntEntry("SETTINGS","fxmmwheellines",4);
  iconpath = getApp()->reg().readStringEntry("SETTINGS","mimeiconpath");
  terminal = getApp()->reg().readStringEntry("SETTINGS","terminal");

  defaultplayer = getApp()->reg().readStringEntry("SETTINGS","defaultplayer");

  fontspec = getApp()->reg().readStringEntry("SETTINGS","bodyfont","");
  if(!fontspec.empty()){
    bodyfont=new FXFont(getApp(),fontspec);
    }

  fontspec2 = getApp()->reg().readStringEntry("SETTINGS","menufont","");
  if(!fontspec2.empty()){
    menufont=new FXFont(getApp(),fontspec2);
    getApp()->setNormalFont(menufont);
    }

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
  // get thumbnailer settings
  thumbnailSize = getApp()->reg().readIntEntry("THUMBNAILER","thumbnailSize",128);
  imageQuality = getApp()->reg().readIntEntry("THUMBNAILER","imageQuality",8);
  filmStripOverlay = getApp()->reg().readBoolEntry("THUMBNAILER","filmStripOverlay",FALSE);
  workaroundIssues = getApp()->reg().readBoolEntry("THUMBNAILER","workaroundIssues",FALSE);
  maintainAspectRatio = getApp()->reg().readBoolEntry("THUMBNAILER","maintainAspectRatio",TRUE);
  smartFrameSelection = getApp()->reg().readBoolEntry("THUMBNAILER","smartFrameSelection",FALSE);
#endif
  autoThumbnailShow = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailShow",TRUE);
  autoThumbnailCreate = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailCreate",FALSE);
  autoThumbnailUpdate = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailUpdate",FALSE);

  imagethumbnailSize = getApp()->reg().readIntEntry("THUMBNAILER","imagethumbnailSize",128);


  // Set the Main Application Target
  setTarget(this);

  // Connect Datatargets
  target_association_type.connect(fileassociation.type);
  target_association_command.connect(fileassociation.command);
  target_association_mimetype.connect(fileassociation.mimetype);
  target_iconpath.connect(iconpath);
  target_terminal.connect(terminal);
  target_wheel.connect(fxmmwheellines);

  target_defaultplayer.connect(defaultplayer);

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
  target_thumbnailSize.connect(thumbnailSize);
  target_imageQuality.connect(imageQuality);
  target_filmStripOverlay.connect(filmStripOverlay);
  target_workaroundIssues.connect(workaroundIssues);
  target_maintainAspectRatio.connect(maintainAspectRatio);
  target_smartFrameSelection.connect(smartFrameSelection);
#endif
  target_autoThumbnailShow.connect(autoThumbnailShow);
  target_autoThumbnailCreate.connect(autoThumbnailCreate);
  target_autoThumbnailUpdate.connect(autoThumbnailUpdate);

  target_imagethumbnailSize.connect(imagethumbnailSize);

  // Set the message identifier for this data target
  setSelector(ID_FXMMAPPLICATION);

  // Retrive theme settings
  theme=getApp()->reg().readStringEntry("SETTINGS","theme");
  // Read Colors
  if(! (theme_fxmmfore=getApp()->reg().readColorEntry("SETTINGS","fxmmforecolor"))) { theme_fxmmfore   = FXRGB(180,180,180);}
  if(! (theme_fxmmback=getApp()->reg().readColorEntry("SETTINGS","fxmmbackcolor"))) { theme_fxmmback   = FXRGB( 20, 20, 20);}
  if(! (theme_fxmmbase=getApp()->reg().readColorEntry("SETTINGS","fxmmbasecolor"))) { theme_fxmmbase   = FXRGB( 60, 60, 60);}
  if(! (theme_fxmmborder=getApp()->reg().readColorEntry("SETTINGS","fxmmbordercolor"))) { theme_fxmmborder = FXRGB(  0,  0,  0);}
  if(! (theme_fxmmmenufore=getApp()->reg().readColorEntry("SETTINGS","fxmmmenuforecolor"))) { theme_fxmmmenufore  = FXRGB(240,240,240);}
  if(! (theme_fxmmmenuback=getApp()->reg().readColorEntry("SETTINGS","fxmmmenubackcolor"))) { theme_fxmmmenuback  = FXRGB( 10, 10, 10);}
  if(! (theme_fxmmselfore=getApp()->reg().readColorEntry("SETTINGS","fxmmselforecolor"))) { theme_fxmmselfore   = FXRGB(  0,  0,  0);}
  if(! (theme_fxmmselback=getApp()->reg().readColorEntry("SETTINGS","fxmmselbackcolor"))) { theme_fxmmselback   = FXRGB(140,140,140);}
  if(! (theme_fxmmtipfore=getApp()->reg().readColorEntry("SETTINGS","fxmmtipforecolor"))) { theme_fxmmtipfore  = FXRGB(220,220,220);}
  if(! (theme_fxmmtipback=getApp()->reg().readColorEntry("SETTINGS","fxmmtipbackcolor"))) { theme_fxmmtipback  = FXRGB( 20, 20, 20);}
  if(! (theme_fxmmhilite=getApp()->reg().readColorEntry("SETTINGS","fxmmhilitecolor"))) { theme_fxmmhilite  = FXRGB(100,100,100);}
  if(! (theme_fxmmshadow=getApp()->reg().readColorEntry("SETTINGS","fxmmshadowcolor"))) { theme_fxmmshadow  = FXRGB( 10, 10, 10);}
  

  // Retrive language settings
  language = getApp()->reg().readStringEntry("SETTINGS","language");
  if(language== "en" || language== "it" || language== "fr" || language== "de" || language== "es" || language== "ru" || language== "cn" || language== "jp" ){
  // Read language
  audiobuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","audiobuttontext1");
  audiobuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","audiobuttontext2");
  dropbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","dropbuttontext1");
  dropbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","dropbuttontext2");
  zoombuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","zoombuttontext1");
  zoombuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","zoombuttontext2");
  loopbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","loopbuttontext1");
  loopbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","loopbuttontext2");
  hidebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","hidebuttontext1");
  hidebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","hidebuttontext2");
  allbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","allbuttontext1");
  allbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","allbuttontext2");
  widebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","widebuttontext1");
  widebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","widebuttontext2");
  imgbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","imgbuttontext1");
  imgbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","imgbuttontext2");
  quitbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","quitbuttontext");
  openbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","openbuttontext");
  stopbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","stopbuttontext");
  pausebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","pausebuttontext");
  playbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","playbuttontext");
  jplaybuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","jplaybuttontext");
  outputbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","outputbuttontext");
  sizebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","sizebuttontext");
  confbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","confbuttontext");
  upbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","upbuttontext");
  downbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","downbuttontext");
  slistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","slistbuttontext");
  olistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","olistbuttontext");
  createbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","createbuttontext");
  recreatebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","recreatebuttontext");
  deletebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","deletebuttontext");
  clearbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","clearbuttontext");
  increasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","increasebuttontext");
  decreasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","decreasebuttontext");
  icnlisttext=getApp()->reg().readStringEntry("LANG_BUTTON","icnlisttext");
  detlisttext=getApp()->reg().readStringEntry("LANG_BUTTON","detlisttext");

  file_n=getApp()->reg().readStringEntry("LANG_MENU","file_n");
  file_t=getApp()->reg().readStringEntry("LANG_MENU","file_t");
  file_s=getApp()->reg().readStringEntry("LANG_MENU","file_s");
  file_m=getApp()->reg().readStringEntry("LANG_MENU","file_m");
  file_u=getApp()->reg().readStringEntry("LANG_MENU","file_u");
  file_g=getApp()->reg().readStringEntry("LANG_MENU","file_g");
  file_a=getApp()->reg().readStringEntry("LANG_MENU","file_a");
  file_l=getApp()->reg().readStringEntry("LANG_MENU","file_l");

  menu_op=getApp()->reg().readStringEntry("LANG_MENU","menu_op");
  menu_ow=getApp()->reg().readStringEntry("LANG_MENU","menu_ow");
  menu_pr=getApp()->reg().readStringEntry("LANG_MENU","menu_pr");
  menu_mi=getApp()->reg().readStringEntry("LANG_MENU","menu_mi");
  menu_re=getApp()->reg().readStringEntry("LANG_MENU","menu_re");
  menu_mo=getApp()->reg().readStringEntry("LANG_MENU","menu_mo");
  menu_sy=getApp()->reg().readStringEntry("LANG_MENU","menu_sy");
  menu_cu=getApp()->reg().readStringEntry("LANG_MENU","menu_cu");
  menu_co=getApp()->reg().readStringEntry("LANG_MENU","menu_co");
  menu_pa=getApp()->reg().readStringEntry("LANG_MENU","menu_pa");
  menu_de=getApp()->reg().readStringEntry("LANG_MENU","menu_de");

  menu_te=getApp()->reg().readStringEntry("LANG_MENU","menu_te");
  menu_he=getApp()->reg().readStringEntry("LANG_MENU","menu_he");
  menu_vi=getApp()->reg().readStringEntry("LANG_MENU","menu_vi");
  menu_ar=getApp()->reg().readStringEntry("LANG_MENU","menu_ar");
  menu_sh=getApp()->reg().readStringEntry("LANG_MENU","menu_sh");
  menu_nd=getApp()->reg().readStringEntry("LANG_MENU","menu_nd");
  menu_rd=getApp()->reg().readStringEntry("LANG_MENU","menu_rd");
  menu_dd=getApp()->reg().readStringEntry("LANG_MENU","menu_dd");
  menu_rf=getApp()->reg().readStringEntry("LANG_MENU","menu_rf");
  menu_ma=getApp()->reg().readStringEntry("LANG_MENU","menu_ma");
  menu_um=getApp()->reg().readStringEntry("LANG_MENU","menu_um");

  menu_up=getApp()->reg().readStringEntry("LANG_MENU","menu_up");
  menu_do=getApp()->reg().readStringEntry("LANG_MENU","menu_do");
  menu_al=getApp()->reg().readStringEntry("LANG_MENU","menu_al");
  menu_da=getApp()->reg().readStringEntry("LANG_MENU","menu_da");
  menu_ap=getApp()->reg().readStringEntry("LANG_MENU","menu_ap");
  menu_in=getApp()->reg().readStringEntry("LANG_MENU","menu_in");
  menu_di=getApp()->reg().readStringEntry("LANG_MENU","menu_di");
  menu_ed=getApp()->reg().readStringEntry("LANG_MENU","menu_ed");
  }

  // Build icons
  logoicon=new FXPNGIcon(getApp(),fxmm64);
  abouticon=new FXGIFIcon(getApp(),b_list);
  conficon=new FXGIFIcon(getApp(),b_conf);
  diricon=new FXGIFIcon(getApp(),m_dir);
  fonticon=new FXGIFIcon(getApp(),m_renamedir);
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);
  execicon=new FXGIFIcon(getApp(),m_console);
  mplayericon=new FXGIFIcon(getApp(),m_mpplay);
  ffplayicon=new FXGIFIcon(getApp(),m_ffplay);
  fxplayericon=new FXGIFIcon(getApp(),m_save);

  darkthemeicon=new FXGIFIcon(getApp(),darktheme);
  gentlethemeicon=new FXGIFIcon(getApp(),gentletheme);
  fogthemeicon=new FXGIFIcon(getApp(),fogtheme);
  shinethemeicon=new FXGIFIcon(getApp(),shinetheme);
  bloodthemeicon=new FXGIFIcon(getApp(),bloodtheme);
  pinkthemeicon=new FXGIFIcon(getApp(),pinktheme);
  seathemeicon=new FXGIFIcon(getApp(),seatheme);
  skythemeicon=new FXGIFIcon(getApp(),skytheme);
  moonthemeicon=new FXGIFIcon(getApp(),moontheme);
  classicthemeicon=new FXGIFIcon(getApp(),classictheme);

  en_flagicon=new FXGIFIcon(getApp(),en_flag);
  it_flagicon=new FXGIFIcon(getApp(),it_flag);
  de_flagicon=new FXGIFIcon(getApp(),de_flag);
  fr_flagicon=new FXGIFIcon(getApp(),fr_flag);
  es_flagicon=new FXGIFIcon(getApp(),es_flag);
  ru_flagicon=new FXGIFIcon(getApp(),ru_flag);
  cn_flagicon=new FXGIFIcon(getApp(),cn_flag);
  jp_flagicon=new FXGIFIcon(getApp(),jp_flag);

  // get the size of normal font and create a new font with size x 2

  getApp()->getNormalFont()->create();

  FXFontDesc fontdescription=getApp()->getNormalFont()->getFontDesc();
  menufont = new FXFont(getApp(),fontdescription);
  menufont->create();

  fontdescription.size = (FXuint) (((double)fontdescription.size) * 2.0);
  titlefont = new FXFont(getApp(),fontdescription);
  titlefont->create();

  languagedialog=new LanguageDialog(this);

  tooltip=new FXToolTip(getApp());

  // Declare reused frames
  FXHorizontalFrame *hframe=NULL;
  FXVerticalFrame   *sframe=NULL;
  FXVerticalFrame   *vframe=NULL;
  FXLabel           *label=NULL;
  FXPacker 	    	*packer;

  // main frame
  FXVerticalFrame   *mainframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  // Get icon margin
  const FXint spacing=(logoicon ? 10 : 20);

  // Create the header
  label=new FXLabel(mainframe," FXMovieManager Configuration",logoicon,LAYOUT_FILL_X|JUSTIFY_LEFT|TEXT_AFTER_ICON,0,0,0,0,spacing,spacing,spacing,spacing);
  label->setBackColor(FXRGB(0,0,0));
  label->setTextColor(FXRGB(255,255,0));
  label->setFont(titlefont);

  new FXSeparator(mainframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  
  FXHorizontalFrame *hmainframe=new FXHorizontalFrame(mainframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  FXVerticalFrame *buttonframe=new FXVerticalFrame(hmainframe,LAYOUT_FILL_Y|LAYOUT_LEFT|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0, 5,5,5,5);
  new FXSeparator(hmainframe,SEPARATOR_GROOVE|LAYOUT_FILL_Y);


  FXSwitcher *switcher = new FXSwitcher(hmainframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);

  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"About",abouticon,switcher,FXSwitcher::ID_OPEN_FIRST,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"HowTo",abouticon,switcher,FXSwitcher::ID_OPEN_SECOND,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"Keyboard",abouticon,switcher,FXSwitcher::ID_OPEN_THIRD,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"MimeTypes",conficon,switcher,FXSwitcher::ID_OPEN_FOURTH,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"Configure",conficon,switcher,FXSwitcher::ID_OPEN_FIFTH,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"Thumbnail",conficon,switcher,FXSwitcher::ID_OPEN_SIXTH,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);


  // About this program
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," About FXMovieManager",NULL,JUSTIFY_CENTER_Y);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  label = new FXLabel(vframe,
	"FXMovieManager is a FileManager with movie thumbnails,\n"
	"it manages a PlayList and act as simple front-end to MPlayer.\n"
	"Copyright (C) 2008,2011 Luigi Ziviani (ziviani_luigi@yahoo.it).\n\n"
	"This program is free software; you can redistribute it\n"
	"and/or modify it under the terms of the GNU General Public\n"
	"License as published by the Free Software Foundation;\n"
	"either version 3 of the License, or(at your option)\n"
	"any later version.\n\n"
	"This program is distributed in the hope that it will be useful,\n"
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
	"See the GNU General Public License for more details.\n\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with this program; if not, write to the \n"
	"Free Software Foundation, Inc.,\n"
	"59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"
	);



  // Help instructions
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," How to use FXMovieManager",NULL,JUSTIFY_CENTER_Y);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  label = new FXLabel(vframe,
	" To manage thumbnails of movie files a list of buttons on the\n"
	" right of the main application area can be used.\n\n"
	" 1)  To Create and Show thumbnails of movie files:\n"
	" select the movies and press the button [Create thumbnails].\n"
	" 2)  To ReCreate the thumbnails:\n"
	" select the movies and press the button [Recreate thumbnails].\n"
	" 3)  To load a movie into the playlist:\n"
	" double click on a movie in the filelist or open the file dialog\n"
	" and select one or more movies keeping [Ctrl] or [Shift] pressed.\n"
	" 4)  To delete hidden directories that store the thumbnails:\n"
	" press the button [Delete Thumbnails]\n"
	" 5)  To associate file extensions to icons, mime-types and commands:\n"
	" Select the button [MimeTypes] in the Current dialog and\n"
	" a window will be displayed where to add new file associations\n"
	" 6)  To change Theme/Language/Font/Terminal:\n"
	" Select the button  [Configure] in the Current dialog and\n"
	" a window will be displayed where to set your preferences\n"
	" 7)  To manages files: right mouse click on the file/files selected\n"
	" 8)  To restore default settings click on the button below\n"
	,NULL,JUSTIFY_LEFT);

  button_restore = new FXButton(vframe,"Restore Default Settings\tRestore predefined settings",execicon,this,ID_RESTORE_SETTINGS,FRAME_RAISED|ICON_BEFORE_TEXT|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,260,32, 1,1,1,1);

  // Short Cut instructions
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," Some keyboard controls are enabled",NULL,JUSTIFY_CENTER_Y);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  label = new FXLabel(vframe,
	"     F1 = show help and configuration dialog\n"
	" Other Function buttons: CTRL manages LEFT Panel\n"
	"     F2 = reverse file selection\n"
	"     F3 = create thunbnails of selected files\n"
	"     F4 = force thumbnails recreation of selected files\n"
	"     F5 = increase thumbnails size of selected files\n"
	"     F6 = decrease thumbnails size of selected files\n"
	"     F7 = show big icon list\n"
	"     F8 = show small icon list\n"
	" Keys: CTRL manages LEFT Panel\n"
	"     Delete = delete selected files\n"
	" Other Keys: CTRL manages LEFT Panel   ALT manages RIGHT Panel\n"
	"     C or c = copy\n"
	"     S or s = symlink\n"
	"     R or r = rename\n"
	"     Z or z = play\n"
	"     A or a = pause\n"
	"     Q or q = quit\n" 
	,NULL,JUSTIFY_LEFT);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(hframe," Mouse Wheel Speed ",execicon,LAYOUT_LEFT|LAYOUT_CENTER_Y|ICON_BEFORE_TEXT);
  mousespinner=new FXSpinner(hframe,4,&target_wheel,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
  mousespinner->setRange(1,20);


  // Content-Types configuration
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(hframe,"Search Path for Icons:",NULL,LAYOUT_CENTER_Y);
  new FXTextField(hframe,2,&target_iconpath,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  new FXButton(hframe,"..",diricon,this,ID_SELECT_ICONPATH,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);

  hframe = new FXHorizontalFrame(vframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  vframe = new FXVerticalFrame(hframe,LAYOUT_FILL_Y,0,0,0,0,5,5,5,5);

  new FXSeparator(hframe,SEPARATOR_GROOVE|LAYOUT_FILL_Y);

  new FXLabel(vframe,"Extensions of File: ");
  sframe = new FXVerticalFrame(vframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
  associationlist = new FXList(sframe,this,ID_SELECT_MIMEASSOCIATION,LAYOUT_FILL_Y|LAYOUT_FILL_X|LIST_BROWSESELECT);
  associationlist->setSortFunc(FXList::ascending);
  FXHorizontalFrame * listbuttonframe = new FXHorizontalFrame(vframe,PACK_UNIFORM_WIDTH|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
  new FXButton(listbuttonframe,"&Insert\tInsert a New Extension",NULL,this,ID_CREATE_MIMEASSOCIATION);
  new FXButton(listbuttonframe,"&Delete\tDelete an Extension",NULL,this,ID_DELETE_MIMEASSOCIATION);
  new FXButton(listbuttonframe,"&Change\tChange the name of an Extension",NULL,this,ID_RENAME_MIMEASSOCIATION);

  vframe = new FXVerticalFrame(hframe,LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0,0,0,0,0,0,0);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Type Name:");
  new FXTextField(packer,2,&target_association_type,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Content-Type [object/format]:");
  mimetypelist = new FXComboBox(packer,1,this,ID_SELECT_MIMETYPE,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|COMBOBOX_NO_REPLACE);
  mimetypelist->setSortFunc(FXList::ascending);
  mimetypelist->setNumVisible(9);
  mimetypelist->appendItem(" ");

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  packer = new FXPacker(vframe,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXLabel(packer,"Open With Command:");
  new FXButton(packer,"..",diricon,this,ID_SELECT_COMMAND,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);
  new FXTextField(packer,2,&target_association_command,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);


  FXMatrix *iconsmatrix=new FXMatrix(vframe,4,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);
  new FXLabel(iconsmatrix,"Normal",NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
  button_bigname = new FXButton(iconsmatrix,"\tChange Normalsize MIME-Type Icon",NULL,this,ID_SELECT_ICONBIG_NAME,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,64,64, 1,1,1,1);
  new FXLabel(iconsmatrix,"Small",NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
  button_smallname = new FXButton(iconsmatrix,"\tChange Smallsize MIME-Type Icon",NULL,this,ID_SELECT_ICONSMALL_NAME,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,64,64, 1,1,1,1);


  // import file associations **********************************************//
  FXString datastring;
  FXString mimetype;

  FXStringDict *filetypes; // The dictionary class maintains a fast-access 
                           // hash table of entities indexed by a character string.

  filetypes = getApp()->reg().find("FILETYPES"); // FILETYPES is the registry section where are contents-type data

  if(filetypes){
    for(FXint i=filetypes->first(); i<filetypes->size(); i=filetypes->next(i)){
      associationlist->appendItem(filetypes->key(i),NULL,NULL,TRUE); 	// Key string of struct FXDictEntry
      datastring = filetypes->data(i); 					// Data of struct FXDictEntry
      mimetype = datastring.section(";",4);
      if (!mimetype.empty() && (mimetypelist->findItem(mimetype)==-1)){
        mimetypelist->appendItem(mimetype);
        }
      }
    }

  associationlist->sortItems();
  mimetypelist->sortItems();
  //***********************************************************************//



  // Preferences
  FXMatrix *framematrix=new FXMatrix(switcher,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);

  new FXLabel(framematrix," Theme selection",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(framematrix," Language selection",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);


  FXMatrix *themesmatrix=new FXMatrix(framematrix,3,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);
  darkthemebutton=new FXButton(themesmatrix,"\tDark Theme",NULL,this,ID_SELECT_THEME_DARK,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  darkthemebutton->setIcon(darkthemeicon);
  darkthemebutton->setBackColor(FXRGB(60, 60, 60));
  gentlethemebutton=new FXButton(themesmatrix,"\tStorm Theme",NULL,this,ID_SELECT_THEME_STORM,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  gentlethemebutton->setIcon(gentlethemeicon);
  gentlethemebutton->setBackColor(FXRGB(110,110,110));
  gentlethemebutton=new FXButton(themesmatrix,"\tGentle Theme",NULL,this,ID_SELECT_THEME_GENTLE,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  gentlethemebutton->setIcon(gentlethemeicon);
  gentlethemebutton->setBackColor(FXRGB(160,160,160));

  fogthemebutton=new FXButton(themesmatrix,"\tFog Theme",NULL,this,ID_SELECT_THEME_FOG,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  fogthemebutton->setIcon(fogthemeicon);
  fogthemebutton->setBackColor(FXRGB(180,180,180));
  shinethemebutton=new FXButton(themesmatrix,"\tShine Theme",NULL,this,ID_SELECT_THEME_SHINE,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  shinethemebutton->setIcon(shinethemeicon);
  shinethemebutton->setBackColor(FXRGB(210,210,210));
  shinethemebutton=new FXButton(themesmatrix,"\tSnow Theme",NULL,this,ID_SELECT_THEME_SNOW,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  shinethemebutton->setIcon(shinethemeicon);
  shinethemebutton->setBackColor(FXRGB(230,230,230));

  bloodthemebutton=new FXButton(themesmatrix,"\tBlood Theme",NULL,this,ID_SELECT_THEME_BLOOD,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  bloodthemebutton->setIcon(bloodthemeicon);
  bloodthemebutton->setBackColor(FXRGB(130, 30, 30));
  bloodthemebutton=new FXButton(themesmatrix,"\tRed Theme",NULL,this,ID_SELECT_THEME_RED,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  bloodthemebutton->setIcon(bloodthemeicon);
  bloodthemebutton->setBackColor(FXRGB(160, 60, 60));
  pinkthemebutton=new FXButton(themesmatrix,"\tPink Theme",NULL,this,ID_SELECT_THEME_PINK,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  pinkthemebutton->setIcon(pinkthemeicon);
  pinkthemebutton->setBackColor(FXRGB(240,180,180));

  seathemebutton=new FXButton(themesmatrix,"\tSea Theme",NULL,this,ID_SELECT_THEME_SEA,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  seathemebutton->setIcon(seathemeicon);
  seathemebutton->setBackColor(FXRGB(30, 30, 130));
  seathemebutton=new FXButton(themesmatrix,"\tBlue Theme",NULL,this,ID_SELECT_THEME_BLUE,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  seathemebutton->setIcon(seathemeicon);
  seathemebutton->setBackColor(FXRGB(60, 60, 160));
  skythemebutton=new FXButton(themesmatrix,"\tSky Theme",NULL,this,ID_SELECT_THEME_SKY,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  skythemebutton->setIcon(skythemeicon);
  skythemebutton->setBackColor(FXRGB(180,180,240));

  moonthemebutton=new FXButton(themesmatrix,"\tMoon Theme",NULL,this,ID_SELECT_THEME_MOON,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  moonthemebutton->setIcon(moonthemeicon);
  moonthemebutton->setBackColor(FXRGB(30, 30, 30));
  classicthemebutton=new FXButton(themesmatrix,"\tClassic Theme",NULL,this,ID_SELECT_THEME_CLASSIC,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  classicthemebutton->setIcon(classicthemeicon);
  classicthemebutton->setBackColor(FXRGB(180,180,180));
  classicthemebutton=new FXButton(themesmatrix,"\tSun Theme",NULL,this,ID_SELECT_THEME_SUN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,90,66, 1,1,1,1);
  classicthemebutton->setIcon(classicthemeicon);
  classicthemebutton->setBackColor(FXRGB(230,230,230));


  FXMatrix *languagesmatrix=new FXMatrix(framematrix,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);
  en_button=new FXButton(languagesmatrix,"\tEN language",NULL,this,ID_SELECT_LANGUAGE_EN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  en_button->setIcon(en_flagicon);
  it_button=new FXButton(languagesmatrix,"\tIT language",NULL,this,ID_SELECT_LANGUAGE_IT,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  it_button->setIcon(it_flagicon);
  de_button=new FXButton(languagesmatrix,"\tDE language",NULL,this,ID_SELECT_LANGUAGE_DE,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  de_button->setIcon(de_flagicon);
  fr_button=new FXButton(languagesmatrix,"\tFR language",NULL,this,ID_SELECT_LANGUAGE_FR,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  fr_button->setIcon(fr_flagicon);
  es_button=new FXButton(languagesmatrix,"\tES language",NULL,this,ID_SELECT_LANGUAGE_ES,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  es_button->setIcon(es_flagicon);
  ru_button=new FXButton(languagesmatrix,"\tRU language",NULL,this,ID_SELECT_LANGUAGE_RU,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  ru_button->setIcon(ru_flagicon);
  cn_button=new FXButton(languagesmatrix,"\tCN language",NULL,this,ID_SELECT_LANGUAGE_CN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  cn_button->setIcon(cn_flagicon);
  jp_button=new FXButton(languagesmatrix,"\tJP language",NULL,this,ID_SELECT_LANGUAGE_JP,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,66, 1,1,1,1);
  jp_button->setIcon(jp_flagicon);
  cu_button=new FXButton(languagesmatrix,"Custom\tCustom language",NULL,this,ID_SELECT_LANGUAGE_CU,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,30, 1,1,1,1);
  cu_setting=new FXButton(languagesmatrix,"Configure\tConfigure Custom Language",NULL,this,ID_CUSTOM_LANGUAGE,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,88,30, 1,1,1,1);

  FXHorizontalFrame *fontframe=new  FXHorizontalFrame(framematrix,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  new FXLabel(fontframe,"Files Font",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(fontframe,"Menus Font",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);

  new FXLabel(framematrix,"Terminal",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);


  FXHorizontalFrame *bfontframe=new  FXHorizontalFrame(framematrix,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  fontbutton = new FXButton(bfontframe,"Click to Select  ",fonticon,this,ID_SELECT_FONT,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);
  if(!fontspec.empty()){
    fontbutton->setFont(bodyfont);
    }
  fontbutton2 = new FXButton(bfontframe,"Click to Select  ",fonticon,this,ID_SELECT_FONT2,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);
  if(!fontspec2.empty()){
    fontbutton2->setFont(menufont);
    }

  hframe = new FXHorizontalFrame(framematrix,LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  new FXTextField(hframe,2,&target_terminal,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  new FXButton(hframe,"..",diricon,this,ID_SELECT_TERMINAL,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|ICON_AFTER_TEXT|FRAME_RAISED|FRAME_THICK);

  //***********************************************************************//



  // Thumbnailer
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
  new FXLabel(vframe," ffmpegthumbnailer options",NULL,JUSTIFY_CENTER_Y);
  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXMatrix *thumbmatrix1=new FXMatrix(vframe,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);

  new FXLabel(thumbmatrix1," thumbnail Size",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXTextField(thumbmatrix1,5,&target_thumbnailSize,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);

  new FXLabel(thumbmatrix1," image Quality",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  FXRealSpinner *qualityspinner = new FXRealSpinner(thumbmatrix1,2,&target_imageQuality,FXDataTarget::ID_VALUE,REALSPIN_CYCLIC|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  qualityspinner->setRange(0,11);

  new FXLabel(thumbmatrix1," film Strip Overlay",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix1,"NO","YES",cancelicon,accepticon,&target_filmStripOverlay,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(thumbmatrix1," workaround Issues",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix1,"NO","YES",cancelicon,accepticon,&target_workaroundIssues,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(thumbmatrix1," maintain Aspect Ratio",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix1,"NO","YES",cancelicon,accepticon,&target_maintainAspectRatio,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(thumbmatrix1," smart Frame Selection",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix1,"NO","YES",cancelicon,accepticon,&target_smartFrameSelection,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
#endif



  new FXLabel(vframe," auto Thumbnailer options",NULL,JUSTIFY_CENTER_Y);
  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXMatrix *thumbmatrix2=new FXMatrix(vframe,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);

  new FXLabel(thumbmatrix2," auto Thumbnail Show",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix2,"NO","YES",cancelicon,accepticon,&target_autoThumbnailShow,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(thumbmatrix2," auto Thumbnail Create",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix2,"NO","YES",cancelicon,accepticon,&target_autoThumbnailCreate,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(thumbmatrix2," auto Thumbnail Update",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXToggleButton(thumbmatrix2,"NO","YES",cancelicon,accepticon,&target_autoThumbnailUpdate,FXDataTarget::ID_VALUE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK);

  new FXLabel(vframe,"autoThumbnailCreate is available only if autoThumbnailShow=TRUE",NULL,TEXTFIELD_INTEGER|LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);



  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  new FXLabel(vframe," Image Preview options",NULL,JUSTIFY_CENTER_Y);
  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXMatrix *thumbmatrix3=new FXMatrix(vframe,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);

  new FXLabel(thumbmatrix3," image Preview Size",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXTextField(thumbmatrix3,5,&target_imagethumbnailSize,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);



  new FXSeparator(vframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXMatrix *playermatrix=new FXMatrix(vframe,5,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);

  new FXLabel(playermatrix," player",NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXTextField(playermatrix,7,&target_defaultplayer,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  mp_button=new FXButton(playermatrix,"mplayer\tmplayer",mplayericon,this,ID_SELECT_PLAYER_MPLAYER,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,86,26, 1,1,1,1);
  ff_button=new FXButton(playermatrix,"ffplay\tffplay",ffplayicon,this,ID_SELECT_PLAYER_FFPLAY,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,86,26, 1,1,1,1);
  fx_button=new FXButton(playermatrix,"fxplayer\tfxplayer",fxplayericon,this,ID_SELECT_PLAYER_FXPLAYER,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,86,26, 1,1,1,1);


  new FXSeparator(mainframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(mainframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  label = new FXLabel(copyright,"FXMovieManager - Settings",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();

  new FXButton(copyright," &Quit or Save",accepticon,this,FXTopWindow::ID_CLOSE,BUTTON_INITIAL|ICON_BEFORE_TEXT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0,20,20);

  }


// Delete window
MimeTypeDialog::~MimeTypeDialog(){
  delete titlefont;
  delete bodyfont;
  if(menufont) delete menufont;
  delete logoicon;
  delete abouticon;
  delete conficon;
  delete diricon;
  delete fonticon;
  delete execicon;
  delete accepticon;
  delete cancelicon;
  delete mplayericon;
  delete ffplayicon;
  delete fxplayericon;

  delete darkthemeicon;
  delete gentlethemeicon;
  delete fogthemeicon;
  delete shinethemeicon;
  delete bloodthemeicon;
  delete pinkthemeicon;
  delete seathemeicon;
  delete skythemeicon;
  delete moonthemeicon;
  delete classicthemeicon;

  delete en_flagicon;
  delete it_flagicon;
  delete de_flagicon;
  delete fr_flagicon;
  delete es_flagicon;
  delete ru_flagicon;
  delete cn_flagicon;
  delete jp_flagicon;
  }


// Search for Icon and load it
static FXIcon *createIconApp(FXApp *app,const FXString& name,const FXString& iconpath){
  FXIconSource iconsource(app);
  FXIcon *icon=NULL;
  FXString fullpath;
  if(FXStat::exists(name)){
    fullpath=name;
    }
  else{
    fullpath=FXPath::search(iconpath,name);
    if(fullpath.empty()) return NULL;
    }
  icon=iconsource.loadIconFile(fullpath);
  if(icon){
    icon->blend(app->getBaseColor());
    icon->create();
    return icon;
    }
  return NULL;
  }


// Update Icon
static void updateIconApp(FXApp* app,FXButton* button,const FXString& path){
  FXIconSource iconsource(app);
  FXIcon *icon=NULL;
  if(button->getIcon()){
    icon=button->getIcon();
    button->setIcon(NULL);
    delete icon;
    icon=NULL;
    }
  icon=iconsource.loadIconFile(path);
  if(icon){
    icon->blend(app->getBaseColor());
    icon->create();
    button->setIcon(icon);
    }
  }


// Save file association entry
void MimeTypeDialog::saveFileAssociation(){
  if(fileassociation.extension.empty()) return;
  FXString added;
  added=fileassociation.command+";"+fileassociation.type+";"+fileassociation.bigname+";"+fileassociation.smallname+";"+fileassociation.mimetype;
  getApp()->reg().writeStringEntry("FILETYPES",fileassociation.extension.text(),added.text());
  }


// Select language
long MimeTypeDialog::onCmdSelectLanguage(FXObject*,FXSelector sel,void*){
switch(FXSELID(sel)){
  case ID_SELECT_LANGUAGE_EN:
	language="en";
	quitbuttontext = "\tQuit\tQuit the application";
	openbuttontext = "\tAdd movies\tAdd movies to the playlist";
	audiobuttontext1 = "\tMute\tMute";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tDrop frames\tDrop frames";
	dropbuttontext2 = "\tAll frames\tAll frames";
	stopbuttontext = "\tStop\tStop MPlayer";
	pausebuttontext = "\tPause\tPause MPlayer";
	playbuttontext = "\tPlay\tPlay the selected movies";
	jplaybuttontext = "JPG\tView\tView as slideshow";
	loopbuttontext1 = "\tLoop\tPlay in loop";
	loopbuttontext2 = "\tOnce\tPlay once";
	zoombuttontext1 = "\tZoom\tZoom video size";
	zoombuttontext2 = "\t1:1\tReal video size";
	hidebuttontext1 = "\tHide\tHide playlist";
	hidebuttontext2 = "\tShow\tShow playlist";
	sizebuttontext = "\tSize\tVideo size";
	outputbuttontext = "\tOutput\tVideo output";
	confbuttontext = "\tConfiguration\tFxMovieManager Configuration";
	upbuttontext = "\tMove one step up\tMove one step up";
	downbuttontext = "\tMove one step down\tMove one step down";
	slistbuttontext = "|_|\tSave playlist\tSave list of movies";
	olistbuttontext = "||>\tLoad playlist\tLoad list of movies";
  	allbuttontext1 = "\tSelect all movies\tSelect all movies";
	allbuttontext2 = "\tDeselect all movies\tDeselect all movies";
	createbuttontext = "\tCreate thumbnails\tCreate thumbnails";
	recreatebuttontext = "\tRecreate thumbnails\tRecreate thumbnails";
  	widebuttontext1 = "\tWide Screen\tShow Wide Screen Thumbnails";
	widebuttontext2 = "\tNormal Screen\tShow Normal Screen Thumbnails";
	deletebuttontext = "\tDelete thumbnails\tDelete thumbnails";
	clearbuttontext = "\tClear the playlist\tClear the playlist";
	increasebuttontext = "\tIncrease thumbnails size\tIncrease thumbnails size";
	decreasebuttontext = "\tDecrease thumbnails size\tDecrease thumbnails size";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
	imgbuttontext1 = "\tDon't show thumbnail images\tDon't show thumbnail images";
	imgbuttontext2 = "\tShow thumbnail images\tShow thumbnail images";
    file_n="Name";
    file_t="Type";
    file_s="Size";
    file_m="Modified date";
    file_u="User";
    file_g="Group";
    file_a="Permissions";
    file_l="Symbolic link";
    menu_op="Open";
    menu_ow="Open with";
    menu_pr="File Properties";
    menu_mi="Movie Properties";
    menu_re="Rename";
    menu_mo="Move";
    menu_sy="Symlink";
    menu_cu="Cut";
    menu_co="Copy";
    menu_pa="Paste";
    menu_de="Delete";
    menu_te="Terminal";
    menu_he="Run here";
    menu_vi="Virus scanner";
    menu_ar="Archive opener";
    menu_sh="Show/Hide";
    menu_nd="New directory";
    menu_rd="Rename directory";
    menu_dd="Delete directory";
    menu_rf="Refresh";
    menu_ma="Connect device";
    menu_um="Disconnect device";
    menu_up="Move Up";
    menu_do="Move Down";
    menu_al="Select All";
    menu_da="Delete All";
    menu_ap="Append Item";
    menu_in="Insert Item";
    menu_di="Delete Item";
    menu_ed="Edit Item name";
	break;
  case ID_SELECT_LANGUAGE_IT:
	language="it";
	quitbuttontext = "\tEsci\tEsci dal programma";
	openbuttontext = "\tAggiungi\tAggiungi films alla lista";
	audiobuttontext1 = "\tMuto\tMuto";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tSfoltisci i frames\tSfoltisci i frames";
	dropbuttontext2 = "\tTutti i frames\tTutti i frames";
	stopbuttontext = "\tInterrompi\tInterrompi MPlayer";
	pausebuttontext = "\tPausa\tPausa MPlayer";
	playbuttontext = "\tGuarda\tGuarda i films selezionati";
	jplaybuttontext = "JPG\tGuarda\tVisualizza come presentazione";
	loopbuttontext1 = "\tContinuamente\tGuarda continuamente";
	loopbuttontext2 = "\tUna Volta\tGuarda un volta";
	zoombuttontext1 = "\tZoom\tZoom del video";
	zoombuttontext2 = "\t1:1\tDimensioni del video reali";
	hidebuttontext1 = "\tNascondi\tNascondi la lista";
	hidebuttontext2 = "\tMostra\tMostra la lista";
	sizebuttontext = "\tDimensioni\tDimensioni video";
	outputbuttontext = "\tUscita\tUscita video";
	confbuttontext = "\tConfigurazione\tConfigurazione di FxMovieManager";
	upbuttontext = "\tMuovi in alto\tMuovi in alto di un gradino";
	downbuttontext = "\tMuovi in basso\tMuovi in basso di un gradino";
	slistbuttontext = "|_|\tSalva la lista\tSalva la lista dei film";
	olistbuttontext = "||>\tCarica la lista\tCarica la lista dei film";
  	allbuttontext1 = "\tSeleziona tutti\tSeleziona tutti i filmati";
	allbuttontext2 = "\tDeseleziona tutti\tDeseleziona tutti i filmati";
	createbuttontext = "\tCrea l'anteprima\tCrea l'anteprima";
	recreatebuttontext = "\tRicrea l'anteprima\tRicrea l'anteprima";
  	widebuttontext1 = "\tWide Screen\tVisualizza Anteprima in modalità Wide Screen";
	widebuttontext2 = "\tSchermo Normale\tVisualizza Anteprima in modalità Normale";
	deletebuttontext = "\tElimina l'anteprima\tElimina l'anteprima";
	clearbuttontext = "\tCancella la lista\tCancella la lista";
	increasebuttontext = "\tIngrandisci l'anteprima\tIngrandisci l'anteprima";
	decreasebuttontext = "\tRiduci l'anteprima\tRiduci l'anteprima";
	detlisttext = "\telenco dettagliato\tvista in modalità elenco dettagliato";
	icnlisttext = "\telenco icona\tvista in modalità elenco icona";
	imgbuttontext1 = "\tNon mostrare le immagini\tNon mostrare l'anteprima delle immagini";
	imgbuttontext2 = "\tMostra le immagini\tMostra l'anteprima delle immagini";
    file_n = "Nome";
    file_t = "Tipo";
    file_s = "Dimensione";
    file_m = "Data modifica";
    file_u = "Utente";
    file_g = "Gruppo";
    file_a = "Autorizzazioni";
    file_l = "Legame simbolico";
    menu_op = "Apri";
    menu_ow = "Apri con";
    menu_pr = "Proprietà File";
    menu_mi = "Proprietà Filmato";
    menu_re = "Rinomina";
    menu_mo = "Muovi";
    menu_sy = "Lega";
    menu_cu = "Taglia";
    menu_co = "Copia";
    menu_pa = "Incolla";
    menu_de = "Elimina";
    menu_te = "Terminale";
    menu_he = "Esegui qui";
    menu_vi = "Scansione Virus";
    menu_ar = "Manager Archivio";
    menu_sh = "Mostra / Nascondi";
    menu_nd = "Nuova cartella";
    menu_rd = "Rinomina cartella";
    menu_dd = "Elimina cartella";
    menu_rf = "Aggiorna visualizzazione";
    menu_ma = "Connetti dispositivo";
    menu_um = "Disconnetti dispositivo";
    menu_up = "Sposta in su";
    menu_do = "Sposta in giù";
    menu_al = "Seleziona tutto";
    menu_da = "Cancella tutto";
    menu_ap = "Aggiungi elemento";
    menu_in = "Inserisci elemento";
    menu_di = "Elimina elemento";
    menu_ed = "Edita nome elemento";
	break;
  case ID_SELECT_LANGUAGE_DE:
	language="de";
	quitbuttontext = "\tBeenden\tFX Movie Manager Beenden";
	openbuttontext = "\tHinzufügen zur Liste Filme\tHinzufügen zur Liste Filme";
	audiobuttontext1 = "\tMute\tMute";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tVerringerung der Bilder\tVerringerung der Bilder";
	dropbuttontext2 = "\tAlle bilder\tAlle bilder";
	stopbuttontext = "\tStoppen\tStoppen MPlayer";
	pausebuttontext = "\tPause\tPause MPlayer";
	playbuttontext = "\tSehen Sie den Film\tSehen Sie sich die ausgewählten Filme";
	jplaybuttontext = "JPG\tDiashow\tAnzeigen als Diashow";
	loopbuttontext1 = "\tKontinuierlich\tSehen Sie den Film kontinuierlich";
	loopbuttontext2 = "\tEinmal\tSchauen Sie einmal";
	zoombuttontext1 = "\tZoom\tZoom Video-Größe";
	zoombuttontext2 = "\t1:1\tReal Video-Größe";
	hidebuttontext1 = "\tAusblenden\tAusblenden der Liste der Filme";
	hidebuttontext2 = "\tZeigt\tZeigt die Liste der Filme";
	sizebuttontext = "\tGröße\tVideo-Größe";
	outputbuttontext = "\tAusgang\tVideo-Ausgang";
	confbuttontext= "\tKonfiguration\tKonfigurieren FxMovieManager";
	upbuttontext= "\tEinen Schritt bis\tBewegen Sie ein Schritt bis";
	downbuttontext= "\tEinen Schritt nach unten\tBewegen Sie ein Schritt nach unten";
	slistbuttontext = "|_|\tListe speichern\tListe der Filme speichern";
	olistbuttontext = "||>\tLast Liste\tLast Liste der Filme";
  	allbuttontext1= "\tWählen Sie alle Filme\tWählen Sie alle Filme";
	allbuttontext2= "\tDeaktivieren Sie alle Filme\tDeaktivieren Sie alle Filme";
	createbuttontext= "\tSchafft Vorschau\tSchafft Vorschau";
	recreatebuttontext= "\tStellt Vorschau\tStellt Vorschau";
  	widebuttontext1 = "\tWide Screen\tVorschau-Modus Wide Screen";
	widebuttontext2 = "\tNormal\tVorschau-Modus Normal";
	deletebuttontext= "\tEliminiert Vorschau\tEliminiert Vorschau";
	clearbuttontext= "\tLöscht die Liste der Filme\tLöscht die Liste der Filme";
	increasebuttontext= "\tVergrössern Vorschau\tVergrössern Vorschau";
	decreasebuttontext= "\tNiederösterreich Vorschau\tNiederösterreich Vorschau";
	detlisttext = "\tdetaillierte Liste\tBlick in detaillierte Liste Modus";
	icnlisttext = "\tListe Symbol\tAnsicht in Liste Symbol-Modus";
	imgbuttontext1 = "\tzeigen keine Miniaturbilder\tzeigen keine Miniaturbilder";
	imgbuttontext2 = "\tBilder anzeigen\tBilder anzeigen";
    file_n = "Name";
    file_t = "Typ";
    file_s = "Größe";
    file_m = "Geändert Datum";
    file_u = "User";
    file_g = "Gruppe";
    file_a = "Berechtigungen";
    file_l = "Bindeglied";
    menu_op = "Öffnen";
    menu_ow = "Öffnen mit";
    menu_pr = "Eigenschaften";
    menu_mi = "Film Eigenschaften";
    menu_re = "Umbenennen";
    menu_mo = "Nach";
    menu_sy = "Verknüpfung";
    menu_cu = "Ausschneiden";
    menu_co = "Kopieren";
    menu_pa = "Einfügen";
    menu_de = "Löschen";
    menu_te = "Terminal";
    menu_he = "Run hier";
    menu_vi = "Virenscanner";
    menu_ar = "Archiv Opener";
    menu_sh = "Zeige / Verstecke";
    menu_nd = "Neues Verzeichnis";
    menu_rd = "Verzeichnis umbenennen";
    menu_dd = "Löschen Sie das Verzeichnis";
    menu_rf = "Aktualisieren";
    menu_ma = "Gerät kein trennen";
    menu_um = "Gerät trennen";
    menu_up = "Nach oben";
    menu_do = "Nach nieder";
    menu_al = "Alle vorgabe";
    menu_da = "Alle löschen";
    menu_ap = "Punkt appendn";
    menu_in = "Punkt einsatz";
    menu_di = "Punkt löschen";
    menu_ed = "Punkt editieren";
	break;
  case ID_SELECT_LANGUAGE_FR:
	language="fr";
	quitbuttontext = "\tQuittez l'application\tQuittez l'application";
	openbuttontext = "\tAjouter à la liste de films\tAjouter à la liste de films";
	audiobuttontext1 = "\tMute\tMute";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tRéduire les images\tRéduire les images";
	dropbuttontext2 = "\tToutes les images\tToutes les images";
	stopbuttontext = "\tArrêter\tArrêter MPlayer";
	pausebuttontext = "\tPause\tPause MPlayer";
	playbuttontext = "\tRegarder\tRegarder les films sélectionnés";
	jplaybuttontext = "JPG\tVoir\tAfficher en tant que diaporama";
	loopbuttontext1 = "\tBoucle\tRegarder en boucle";
	loopbuttontext2 = "\tOne fois\tRegarder une fois";
	zoombuttontext1 = "\tZoom\tZoom taille vidéo";
	zoombuttontext2 = "\t1:1\t1:1 taille vidéo";
	hidebuttontext1 = "\tMasquer\tMasquer la liste de film";
	hidebuttontext2 = "\tVoir\tVoir la liste de film";
	sizebuttontext = "\tTaille\ttaille de la vidéo";
	outputbuttontext = "\tSortie\tSortie vidéo";
	confbuttontext = "\tConfiguration\tConfigurer FxMovieManager";
	upbuttontext = "\tDéplacer vers le haut\tDéplacer vers le haut";
	downbuttontext = "\tDéplacez vers le bas\tDéplacez vers le bas";
	slistbuttontext = "|_|\tMettre la liste\tMettre la liste de film";
	olistbuttontext = "||>\tCharge de la liste\tCharge de la liste de film";
  	allbuttontext1 = "\tSélectionnez tous les films\tSélectionnez tous les films";
	allbuttontext2 = "\tDésactivez tous les films\tDésactivez tous les films";
	createbuttontext = "\tCrée une prévisualisation\tCrée une prévisualisation";
	recreatebuttontext = "\tRecrée une prévisualisation\tRecrée une prévisualisation";
  	widebuttontext1 = "\tWide Screen\tVoir les prévisualisation dans le mode Wide Screen";
	widebuttontext2 = "\tEcran Normal\tVoir les prévisualisation dans le mode Normal";
	deletebuttontext = "\tSupprimer une prévisualisation\tSupprimer une prévisualisation";
	clearbuttontext = "\tEffacer la liste de film\tEffacer la liste de film";
	increasebuttontext = "\tAugmenter la taille de prévisualisation\tAugmenter la taille de prévisualisation";
	decreasebuttontext = "\tDiminution de prévisualisation\tDiminution de prévisualisation";
	detlisttext = "\tliste détaillée\tvue en mode liste détaillée";
	icnlisttext = "\tliste d'icônes\tvue en liste d'icônes mode";
	imgbuttontext1 = "\tNe pas afficher les images miniatures\tNe pas afficher les images miniatures";
	imgbuttontext2 = "\tAfficher des miniatures\tAfficher des miniatures";
    file_n = "Nom";
    file_t = "Type";
    file_s = "Taille";
    file_m = "Date de modification";
    file_u = "Utilisateur";
    file_g = "Groupe";
    file_a = "Autorisations";
    file_l = "Symlink";
    menu_op = "Ouvrir";
    menu_ow = "Ouvrir avec";
    menu_pr = "Propriétés";
    menu_mi = "Propriétés de le film";
    menu_re = "Renommer";
    menu_mo = "Déplacer";
    menu_sy = "Symlink";
    menu_cu = "Couper";
    menu_co = "Copier";
    menu_pa = "Coller";
    menu_de = "Supprimer";
    menu_te = "Terminal";
    menu_he = "Exécuter ici";
    menu_vi = "Scanner de virus";
    menu_ar = "Ouvre Archive";
    menu_sh = "Afficher / Masquer";
    menu_nd = "Nouveau répertoire";
    menu_rd = "Renommer le répertoire";
    menu_dd = "Supprimer le répertoire";
    menu_rf = "Actualiser";
    menu_ma = "Connect le dispositif";
    menu_um = "Disconnect le dispositif";
    menu_up = "Déplacer vers le haut";
    menu_do = "Déplacer vers le bas";
    menu_al = "Sélectionner tout";
    menu_da = "Supprimer tout";
    menu_ap = "Append l'élément";
    menu_in = "Insérer l'élément";
    menu_di = "Supprimer l'élément";
    menu_ed = "Éditer l'élément";
	break;
  case ID_SELECT_LANGUAGE_ES:
	language="es";
	quitbuttontext = "\tSalir del programa\tSalir del programa";
	openbuttontext = "\tAñadir a la lista de películas\tAñadir a la lista de películas";
	audiobuttontext1 = "\tMudo\tMudo";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tReducir las imágenes\tReducir las imágenes";
	dropbuttontext2 = "\tTodas las imágenes\tTodas las imágenes";
	stopbuttontext = "\tParar\tParar MPlayer";
	pausebuttontext = "\tRomper\tRomper MPlayer";
	playbuttontext = "\tMira\tMira las películas seleccionadas";
	jplaybuttontext = "JPG\tVer\tVer como presentación de diapositivas";
	loopbuttontext1 = "\tContinua\tMira continua";
	loopbuttontext2 = "\tUna vez\tMira una vez";
	zoombuttontext1 = "\tZoom\tVideo Zoom";
	zoombuttontext2 = "\t1:1\tTamaño real del video";
	hidebuttontext1 = "\tOcultar\tOcultar la lista de películas";
	hidebuttontext2 = "\tMuestra\tMuestra la lista de películas";
	sizebuttontext = "\tTamaño\tel tamaño video";
	outputbuttontext = "\tSalida\tsalida de vídeo";
	confbuttontext = "\tConfiguración\tConfiguración de FXMovieManager";
	upbuttontext = "\tSales de un paso\tSales de un paso";
	downbuttontext = "\tBajar un paso\tBajar un paso";
	slistbuttontext = "|_|\tGuardar la lista\tGuardar la lista de películas";
	olistbuttontext = "||>\tCarga de la lista\tCarga de la lista de películas";
	allbuttontext1 = "\tSeleccione todas las películas\tSeleccione todas las películas";
	allbuttontext2 = "\tDesmarque todas las películas\tDesmarque todas las películas";
	createbuttontext = "\tCrear una vista previa\tCrear una vista previa";
	recreatebuttontext = "\tRecrear la vista previa\tRecrear la vista previa";
  	widebuttontext1 = "\tWide Screen\tMostrar vista previa en modo de pantalla ancha";
	widebuttontext2 = "\tNormal Screen\tMostrar vista previa en modo de pantalla normal";
	deletebuttontext = "\tEliminar la vista previa\tEliminar la vista previa";
	clearbuttontext = "\tBorrar la lista de películas\tBorrar la lista de películas";
	increasebuttontext = "\tAmpliar la vista previa\tAmpliar la vista previa";
	decreasebuttontext = "\tMenos de vista previa\tMenos de vista previa";
	detlisttext = "\tlista detallada\tver lista detallada en el modo";
	icnlisttext = "\ticono de lista\ticono de vista en modo lista";
	imgbuttontext1 = "\tno mostrar las imágenes en miniatura\tno mostrar las imágenes en miniatura";
	imgbuttontext2 = "\tMostrar imágenes en miniatura\tMostrar imágenes en miniatura";
    file_n = "Nombre";
    file_t = "Tipo";
    file_s = "Tamaño";
    file_m = "Fecha de modificación";
    file_u = "Usuario";
    file_g = "Grupo";
    file_a = "Permisos";
    file_l = "Enlace simbólico";
    menu_op = "Abrir";
    menu_ow = "Abrir con";
    menu_pr = "Propiedades";
    menu_mi = "Propiedades de la película";
    menu_re = "Cambiar nombre";
    menu_mo = "Mover";
    menu_sy = "Enlace simbólico";
    menu_cu = "Cortar";
    menu_co = "Copiar";
    menu_pa = "Pegar";
    menu_de = "Eliminar";
    menu_te = "Terminal";
    menu_he = "Ejecutar aquí";
    menu_vi = "Escáner de virus";
    menu_ar = "Abrir archivo";
    menu_sh = "Mostrar / Ocultar";
    menu_nd = "Nuevo directorio";
    menu_rd = "Cambiar el nombre de directorio";
    menu_dd = "Borrar directorio";
    menu_rf = "Actualizar";
    menu_ma = "Conexión de dispositivo";
    menu_um = "Desconexión  de dispositivo";
    menu_up = "Mover arriba";
    menu_do = "Mover abajo";
    menu_al = "Seleccionar todo";
    menu_da = "Borrar todo";
    menu_ap = "Añadir elemento";
    menu_in = "Insertar elemento";
    menu_di = "Eliminar elemento";
    menu_ed = "Editar elemento";
	break;
  case ID_SELECT_LANGUAGE_RU:
	language="ru";
	quitbuttontext = "\tВыйти\tВыйти из FX Movie Manager";
	openbuttontext = "\tприбавлять\tприбавлять";
	audiobuttontext1 = "\tнемой\tнемой";
	audiobuttontext2 = "\tзвукозапись\tзвукозапись";
	dropbuttontext1 = "\tменьший\tменьший";
	dropbuttontext2 = "\tвсякая всячина\tвсякая всячина";
	stopbuttontext = "\tостановка\tостановка";
	pausebuttontext = "\tпауза\tпауза";
	playbuttontext = "\tвоспроизводить\tвоспроизводить";
	jplaybuttontext = "JPG\tвыставка картин\tвыставка картин";
	loopbuttontext1 = "\tнепрерывно\tнепрерывно";
	loopbuttontext2 = "\tодин раз\tодин раз";
	zoombuttontext1 = "\tгудящий звук \tгудящий звук телевидение";
	zoombuttontext2 = "\t1:1\tнормализация телевидение";
	hidebuttontext1 = "\tшкура\tшкура";
	hidebuttontext2 = "\tпоказ\tпоказ";
	sizebuttontext = "\tразмер\tразмер телевидение";
	outputbuttontext = "\tвитрина\tвитрина телевидение";
	confbuttontext = "\tКонфигурация\tНастройка FxMovieManager";
	upbuttontext = "\tподниматься\tподниматься";
	downbuttontext = "\tспускаться\tспускаться";
	slistbuttontext = "|_|\tзапас\tзапас";
	olistbuttontext = "||>\tгруз\tгруз";
  	allbuttontext1 = "\tвсякая всячина\tвсякая всячина";
	allbuttontext2 = "\tпустяк\tпустяк";
	createbuttontext = "\tсоздавать миниатюра\tсоздавать миниатюра";
	recreatebuttontext = "\tвновь создавать миниатюра\tвновь создавать миниатюра";
  	widebuttontext1 = "\tпростор ширма\tпростор ширма";
	widebuttontext2 = "\tзнамя ширма\tзнамя ширма";
	deletebuttontext = "\tвычеркивать миниатюра\tвычеркивать миниатюра";
	clearbuttontext = "\tвыметание\tвыметание список";
	increasebuttontext = "\tувеличение миниатюра\tувеличение миниатюра";
	decreasebuttontext = "\tуменьшение миниатюра\tуменьшение миниатюра";
	detlisttext = "\tподробно\tсписок подробно";
	icnlisttext = "\tикона\tсписок икона";
	imgbuttontext1 = "\tшкура миниатюра\tшкура миниатюра";
	imgbuttontext2 = "\tпоказ миниатюра\tпоказ миниатюра";
    file_n = "имя";
    file_t = "тип";
    file_s = "размер";
    file_m = "время";
    file_u = "собственник";
    file_g = "группа";
    file_a = "разрешение";
    file_l = "сцепление";
    menu_op = "Открыть";
    menu_ow = "Открыть с помощью";
    menu_pr = "Свойства";
    menu_mi = "Свойства";
    menu_re = "Переименовать";
    menu_mo = "Переместить";
    menu_sy = "Символьная ссылка";
    menu_cu = "Вырезать";
    menu_co = "Копировать";
    menu_pa = "Вставить";
    menu_de = "Удалить";
    menu_te = "Терминал";
    menu_he = "Run здесь";
    menu_vi = "Антивирусный сканер";
    menu_ar = "Архив нож";
    menu_sh = "Показать / Скрыть";
    menu_nd = "Создать директорию";
    menu_rd = "Переименовать каталога";
    menu_dd = "Удалить каталог";
    menu_rf = "Обновить";
    menu_ma = "Подключение устройств";
    menu_um = "Отключить устройство";
    menu_up = "пододвинуться";
    menu_do = "спускаться";
    menu_al = "Выделить все";
    menu_da = "Удалить все";
    menu_ap = "Добавить пункт";
    menu_in = "Вставить объект";
    menu_di = "Удалить элемент";
    menu_ed = "Редактировать";	
	break;
  case ID_SELECT_LANGUAGE_CN:
	language="cn";
	quitbuttontext = "\t退出\t关于 FX Movie Manager";
	openbuttontext = "\t添加电影\t电影添加到播放列表";
	audiobuttontext1 = "\t静音\t静音";
	audiobuttontext2 = "\t音频\t音频";
	dropbuttontext1 = "\t丢弃帧\t丢弃帧";
	dropbuttontext2 = "\t所有框架\t所有框架";
	stopbuttontext = "\t停止\t停止播放";
	pausebuttontext = "\t暂停\t暂停";
	playbuttontext = "\t玩\t播放所选的电影";
	jplaybuttontext = "JPG\t玩\t视幻灯片放映";
	loopbuttontext1 = "\t环\t在循环播放";
	loopbuttontext2 = "\t一次\t玩一次";
	zoombuttontext1 = "\t变焦\t变焦视频尺寸";
	zoombuttontext2 = "\t1:1\t真实视频尺寸";
	hidebuttontext1 = "\t隐藏\t隐藏播放列表";
	hidebuttontext2 = "\t显示\t显示播放列表";
	sizebuttontext = "\t大小\t改变视频尺寸";
	outputbuttontext = "\t输出\t更改视频输出";
	confbuttontext = "\t配置\tFxMovieManager配置";
	upbuttontext = "\t移动一个加强\t移动一个加强";
	downbuttontext = "\t移动一个下台\t移动一个下台";
	slistbuttontext = "|_|\t保存电影列表\t保存电影列表";
	olistbuttontext = "||>\t负载电影列表\t负载电影列表";
  	allbuttontext1 = "\t选择所有电影\t选择所有电影";
	allbuttontext2 = "\t取消所有电影\t取消所有电影";
	createbuttontext = "\t创建缩略图\t创建缩略图";
	recreatebuttontext = "\t重新创建缩略图\t重新创建缩略图";
  	widebuttontext1 = "\t宽屏幕\t宽屏幕显示缩略图";
	widebuttontext2 = "\t普通屏幕\t普通屏幕显示缩略图";
	deletebuttontext = "\t删除缩略图\t删除缩略图";
	clearbuttontext = "\t清除播放列表\t清除播放列表";
	increasebuttontext = "\t增加缩略图的尺寸\t增加缩略图的尺寸";
	decreasebuttontext = "\t缩略图的尺寸减少\t缩略图的尺寸减少";
	detlisttext = "\t详细列表视图\t详细列表视图";
	icnlisttext = "\t图标列表视图\t图标列表视图";
	imgbuttontext1 = "\t不显示缩略图\t不显示缩略图";
	imgbuttontext2 = "\t显示缩略图\t显示缩略图";
    file_n = "名称";
    file_t = "类型";
    file_s = "大小";
    file_m = "修改日期";
    file_u = "用户";
    file_g = "集团";
    file_a = "权限";
    file_l = "符号链接";
    menu_op = "打开";
    menu_ow = "打开方式";
    menu_pr = "属性";
    menu_mi = "属性";
    menu_re =  "重命名";
    menu_mo = "移动";
    menu_sy = "符号链接";
    menu_cu = "剪切";
    menu_co = "复制";
    menu_pa = "粘贴";
    menu_de = "删除";
    menu_te = "终端";
    menu_he = "运行在这里";
    menu_vi = "病毒扫描";
    menu_ar = "存档器";
    menu_sh = "显示/隐藏";
    menu_nd = "新目录";
    menu_rd = "重命名目录";
    menu_dd = "删除目录";
    menu_rf = "刷新";
    menu_ma = "连接设备";
    menu_um = "断开装置";
    menu_up = "上移";
    menu_do = "下移";
    menu_al = "全选";
    menu_da = "删除所有";
    menu_ap = "附加项目";
    menu_in = "插入项目";
    menu_di = "删除项目";
    menu_ed = "编辑";
	break;
  case ID_SELECT_LANGUAGE_JP:
	language="jp";
	quitbuttontext = "\t終了する\tプログラムの終了";
	openbuttontext = "\t作品を追加\tプレイリストに作品を追加";
	audiobuttontext1 = "\tミュート\tミュート";
	audiobuttontext2 = "\tオーディオ\tオーディオ";
	dropbuttontext1 = "\tドロップフレーム\tドロップフレーム";
	dropbuttontext2 = "\tすべてのフレームを\tすべてのフレームを";
	stopbuttontext = "\t停止する\t停止プレーヤー";
	pausebuttontext = "\t一時停止\t一時停止";
	playbuttontext = "\t遊ぶ\t再生する映画を選択";
	jplaybuttontext = "JPG\t遊ぶ\tスライドショーとして表示";
	loopbuttontext1 = "\tループ\tループ内で再生";
	loopbuttontext2 = "\t一度\t再生1回";
	zoombuttontext1 = "\tズーム\tズームビデオサイズ";
	zoombuttontext2 = "\t1:1\tリアルビデオのサイズ";
	hidebuttontext1 = "\t隠す\tプレイリストを隠す";
	hidebuttontext2 = "\t見せる\t表示されるプレイリスト";
	sizebuttontext = "\t寸法\tビデオサイズ";
	outputbuttontext = "\t出力\tビデオ出力";
	confbuttontext = "\t構成\tFxMovieManager構成";
	upbuttontext = "\t一歩上に移動\t一歩上に移動";
	downbuttontext = "\t移動する1つのステップダウン\t移動する1つのステップダウン";
	slistbuttontext = "|_|\t保存プレイリスト\t保存プレイリスト";
	olistbuttontext = "||>\t負荷プレイリスト\t負荷プレイリスト";
  	allbuttontext1 = "\t選択したすべて\t選択して、すべてのムービー";
	allbuttontext2 = "\tすべて選択解除\t選択をすべて解除映画";
	createbuttontext = "\tサムネールを作成します。\tサムネールを作成します。";
	recreatebuttontext = "\tを再現サムネイル\tを再現サムネイル";
  	widebuttontext1 = "\tワイドスクリーン\t地図をワイドスクリーンのサムネイル";
	widebuttontext2 = "\tノーマル画面\t地図を標準の画面のサムネイル";
	deletebuttontext = "\t削除サムネイル\t削除サムネイル";
	clearbuttontext = "\tクリアプレイリスト\tクリアプレイリスト";
	increasebuttontext = "\tサムネイルのサイズを増やします。\tサムネイルのサイズを増やします。";
	decreasebuttontext = "\t減少サイズのサムネイル\t減少サイズのサムネイル";
	detlisttext = "\t詳細なリストを表示\t詳細なリストを表示";
	icnlisttext = "\tアイコンの一覧を表示\tアイコンの一覧を表示";
	imgbuttontext1 = "\tサムネイル画像を表示しない\tサムネイル画像を表示しない";
	imgbuttontext2 = "\t表示するサムネイル画像\t表示するサムネイル画像";
    file_n = "名称";
    file_t = "タイプ";
    file_s = "サイズ";
    file_m = "更新日時";
    file_u = "ユーザー";
    file_g = "グループ";
    file_a = "アクセス権";
    file_l = "シンボリックリンク";
    menu_op = "開く";
    menu_ow = "とオープン。";
    menu_pr = "プロパティ";
    menu_mi = "プロパティ";
    menu_re = "名前の変更";
    menu_mo = "移動";
    menu_sy = "シンボリックリンク";
    menu_cu = "切り取り";
    menu_co = "コピー";
    menu_pa = "貼り付け";
    menu_de = "削除";
    menu_te = "ターミナル";
    menu_he = "実行ここ";
    menu_vi = "ウイルススキャナ";
    menu_ar = "アーカイブ開幕";
    menu_sh = "表示/非表示";
    menu_nd = "新規ディレクトリ";
    menu_rd = "名前の変更ディレクトリ";
    menu_dd = "ディレクトリを削除する";
    menu_rf = "更新";
    menu_ma = "接続デバイス";
    menu_um = "切断装置";
    menu_up = "アップに移動します。";
    menu_do = "ダウンに移動。";
    menu_al = "すべて選択";
    menu_da = "すべて削除";
    menu_ap = "追加アイテム";
    menu_in = "項目の挿入";
    menu_di = "アイテムの削除";
    menu_ed = "編集";
	break;
  case ID_SELECT_LANGUAGE_CU:
  language="cu";
  audiobuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext1");
  audiobuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext2");
  dropbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext1");
  dropbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext2");
  zoombuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext1");
  zoombuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext2");
  loopbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext1");
  loopbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext2");
  hidebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext1");
  hidebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext2");
  allbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext1");
  allbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext2");
  widebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext1");
  widebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext2");
  imgbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext1");
  imgbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext2");
  quitbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","quitbuttontext");
  openbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","openbuttontext");
  stopbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","stopbuttontext");
  pausebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","pausebuttontext");
  playbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","playbuttontext");
  jplaybuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","jplaybuttontext");
  outputbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","outputbuttontext");
  sizebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","sizebuttontext");
  confbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","confbuttontext");
  upbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","upbuttontext");
  downbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","downbuttontext");
  slistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","slistbuttontext");
  olistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","olistbuttontext");
  createbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","createbuttontext");
  recreatebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","recreatebuttontext");
  deletebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","deletebuttontext");
  clearbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","clearbuttontext");
  increasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","increasebuttontext");
  decreasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","decreasebuttontext");
  icnlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","icnlisttext");
  detlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","detlisttext");

  file_n=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_n");
  file_t=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_t");
  file_s=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_s");
  file_m=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_m");
  file_u=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_u");
  file_g=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_g");
  file_a=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_a");
  file_l=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_l");

  menu_op=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_op");
  menu_ow=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ow");
  menu_pr=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pr");
  menu_mi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mi");
  menu_re=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_re");
  menu_mo=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mo");
  menu_sy=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sy");
  menu_cu=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_cu");
  menu_co=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_co");
  menu_pa=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pa");
  menu_de=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_de");

  menu_te=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_te");
  menu_he=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_he");
  menu_vi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_vi");
  menu_ar=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ar");
  menu_sh=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sh");
  menu_nd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_nd");
  menu_rd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rd");
  menu_dd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_dd");
  menu_rf=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rf");
  menu_ma=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ma");
  menu_um=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_um");

  menu_up=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_up");
  menu_do=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_do");
  menu_al=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_al");
  menu_da=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_da");
  menu_ap=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ap");
  menu_in=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_in");
  menu_di=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_di");
  menu_ed=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ed");
  break;
  }
  return 1;
}

  // Save Language in the registry file
void MimeTypeDialog::saveLanguage(){
  getApp()->reg().writeStringEntry("SETTINGS","language",language.text());
  // Write language
  getApp()->reg().writeStringEntry("LANG_BUTTON","audiobuttontext1",audiobuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","audiobuttontext2",audiobuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","dropbuttontext1",dropbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","dropbuttontext2",dropbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","zoombuttontext1",zoombuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","zoombuttontext2",zoombuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","loopbuttontext1",loopbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","loopbuttontext2",loopbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","hidebuttontext1",hidebuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","hidebuttontext2",hidebuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","allbuttontext1",allbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","allbuttontext2",allbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","widebuttontext1",widebuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","widebuttontext2",widebuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","imgbuttontext1",imgbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","imgbuttontext2",imgbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","quitbuttontext",quitbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","openbuttontext",openbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","stopbuttontext",stopbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","pausebuttontext",pausebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","playbuttontext",playbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","jplaybuttontext",jplaybuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","outputbuttontext",outputbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","sizebuttontext",sizebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","confbuttontext",confbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","upbuttontext",upbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","downbuttontext",downbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","slistbuttontext",slistbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","olistbuttontext",olistbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","createbuttontext",createbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","recreatebuttontext",recreatebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","deletebuttontext",deletebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","clearbuttontext",clearbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","increasebuttontext",increasebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","decreasebuttontext",decreasebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","icnlisttext",icnlisttext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON","detlisttext",detlisttext.text());


  getApp()->reg().writeStringEntry("LANG_MENU","file_n",file_n.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_t",file_t.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_s",file_s.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_m",file_m.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_u",file_u.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_g",file_g.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_a",file_a.text());
  getApp()->reg().writeStringEntry("LANG_MENU","file_l",file_l.text());

  getApp()->reg().writeStringEntry("LANG_MENU","menu_op",menu_op.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_ow",menu_ow.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_pr",menu_pr.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_mi",menu_mi.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_re",menu_re.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_mo",menu_mo.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_sy",menu_sy.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_cu",menu_cu.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_co",menu_co.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_pa",menu_pa.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_de",menu_de.text());

  getApp()->reg().writeStringEntry("LANG_MENU","menu_te",menu_te.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_he",menu_he.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_vi",menu_vi.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_ar",menu_ar.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_sh",menu_sh.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_nd",menu_nd.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_rd",menu_rd.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_dd",menu_dd.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_rf",menu_rf.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_ma",menu_ma.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_um",menu_um.text());

  getApp()->reg().writeStringEntry("LANG_MENU","menu_up",menu_up.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_do",menu_do.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_al",menu_al.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_da",menu_da.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_ap",menu_ap.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_in",menu_in.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_di",menu_di.text());
  getApp()->reg().writeStringEntry("LANG_MENU","menu_ed",menu_ed.text());
}


// Select theme colors
long MimeTypeDialog::onCmdSelectThemeColors(FXObject*,FXSelector sel,void*){
    switch(FXSELID(sel)){
	case ID_SELECT_THEME_DARK:
  		theme="dark";
  		theme_fxmmfore   = FXRGB(200,200,200);
  		theme_fxmmbase   = FXRGB( 60, 60, 60);
  		theme_fxmmborder = FXRGB(  0,  0,  0);
  		theme_fxmmback   = FXRGB( 20, 20, 20);
  		theme_fxmmmenufore  = FXRGB(200,200,200);
  		theme_fxmmmenuback  = FXRGB( 10, 10, 10);
  		theme_fxmmselfore   = FXRGB(  0,  0,  0);
  		theme_fxmmselback   = FXRGB(100,100,100);
  		theme_fxmmtipfore  = FXRGB(200,200,200);
  		theme_fxmmtipback  = FXRGB( 20, 20, 20);
  		theme_fxmmhilite  = FXRGB(100,100,100);
  		theme_fxmmshadow  = FXRGB( 10, 10, 10);
	break;
	case ID_SELECT_THEME_STORM:
  		theme="storm";
  		theme_fxmmfore   = FXRGB(  0,  0,  0);
  		theme_fxmmbase   = FXRGB(110,110,110);
  		theme_fxmmborder = FXRGB( 20, 20, 20);
  		theme_fxmmback   = FXRGB(140,140,140);
  		theme_fxmmmenufore  = FXRGB(220,220,220);
  		theme_fxmmmenuback  = FXRGB(50, 50, 50);
  		theme_fxmmselfore   = FXRGB(200,200,200);
  		theme_fxmmselback   = FXRGB(70, 70, 70);
  		theme_fxmmtipfore  = FXRGB(200,200,200);
  		theme_fxmmtipback  = FXRGB(70,70,70);
  		theme_fxmmhilite  = FXRGB(120,120,120);
  		theme_fxmmshadow  = FXRGB(50,50,50);
	break;
	case ID_SELECT_THEME_GENTLE:
  		theme="gentle";
  		theme_fxmmfore   = FXRGB(  0,  0,  0);
  		theme_fxmmbase   = FXRGB(160,160,160);
  		theme_fxmmborder = FXRGB( 40, 40, 40);
  		theme_fxmmback   = FXRGB(220,220,220);
  		theme_fxmmmenufore  = FXRGB(  0,  0,  0);
  		theme_fxmmmenuback  = FXRGB(200,200,200);
  		theme_fxmmselfore   = FXRGB(  0,  0,  0);
  		theme_fxmmselback   = FXRGB(180,180,180);
  		theme_fxmmtipfore  = FXRGB( 50, 50, 50);
  		theme_fxmmtipback  = FXRGB(210,210,210);
  		theme_fxmmhilite  = FXRGB(180,180,180);
  		theme_fxmmshadow  = FXRGB(90,90,90);
	break;

	case ID_SELECT_THEME_FOG:
  		theme="fog";
  		theme_fxmmfore   = FXRGB(  0,  0,  0);
  		theme_fxmmbase   = FXRGB(180,180,180);
  		theme_fxmmborder = FXRGB( 50, 50, 50);
  		theme_fxmmback   = FXRGB(230,230,230);
  		theme_fxmmmenufore  = FXRGB(  0,  0,  0);
  		theme_fxmmmenuback  = FXRGB(200,200,200);
  		theme_fxmmselfore   = FXRGB(  0,  0,  0);
  		theme_fxmmselback   = FXRGB(180,180,180);
  		theme_fxmmtipfore  = FXRGB( 50, 50, 50);
  		theme_fxmmtipback  = FXRGB(210,210,210);
  		theme_fxmmhilite  = FXRGB(200,200,200);
  		theme_fxmmshadow  = FXRGB(110,110,110);
	break;
	case ID_SELECT_THEME_SHINE:
  		theme="shine";
  		theme_fxmmfore   = FXRGB(80,80,80);
  		theme_fxmmbase   = FXRGB(210,210,210);
  		theme_fxmmborder = FXRGB(70, 70, 70);
  		theme_fxmmback   = FXRGB(240,240,240);
  		theme_fxmmmenufore  = FXRGB( 30, 30, 30);
  		theme_fxmmmenuback  = FXRGB(190,190,190);
  		theme_fxmmselfore   = FXRGB( 30, 30, 30);
  		theme_fxmmselback   = FXRGB(200,200,200);
  		theme_fxmmtipfore  = FXRGB(70, 70, 70);
  		theme_fxmmtipback  = FXRGB(230,230,230);
  		theme_fxmmhilite  = FXRGB(230,230,230);
  		theme_fxmmshadow  = FXRGB(140,140,140);
	break;
	case ID_SELECT_THEME_SNOW:
  		theme="snow";
  		theme_fxmmfore   = FXRGB(100,100,100);
  		theme_fxmmbase   = FXRGB(230,230,230);
  		theme_fxmmborder = FXRGB( 80, 80, 80);
  		theme_fxmmback   = FXRGB(250,250,250);
  		theme_fxmmmenufore  = FXRGB( 50, 50, 50);
  		theme_fxmmmenuback  = FXRGB(180,180,180);
  		theme_fxmmselfore   = FXRGB( 50, 50, 50);
  		theme_fxmmselback   = FXRGB(220,220,220);
  		theme_fxmmtipfore  = FXRGB(100,100,100);
  		theme_fxmmtipback  = FXRGB(250,250,250);
  		theme_fxmmhilite  = FXRGB(250,250,250);
  		theme_fxmmshadow  = FXRGB(160,160,160);
	break;
	case ID_SELECT_THEME_BLOOD:
  		theme="blood";
  		theme_fxmmfore   = FXRGB( 240,160,160);
  		theme_fxmmbase   = FXRGB(130, 30, 30);
  		theme_fxmmborder = FXRGB( 80, 20, 20);
  		theme_fxmmback   = FXRGB(80, 20, 20);
  		theme_fxmmmenufore = FXRGB( 40,  0,  0);
  		theme_fxmmmenuback = FXRGB(200,100,100);
  		theme_fxmmselfore  = FXRGB( 40,  0,  0);
  		theme_fxmmselback  = FXRGB(180,100,100);
  		theme_fxmmtipfore  = FXRGB( 90, 50, 50);
  		theme_fxmmtipback  = FXRGB(210,160,160);
  		theme_fxmmhilite  = FXRGB(180, 80, 80);
  		theme_fxmmshadow  = FXRGB(80, 20, 20);
	break;
	case ID_SELECT_THEME_RED:
  		theme="red";
  		theme_fxmmfore   = FXRGB(250,180,180 );
  		theme_fxmmbase   = FXRGB(160, 60, 60);
  		theme_fxmmborder = FXRGB( 80, 20, 20);
  		theme_fxmmback   = FXRGB(120, 40, 40);
  		theme_fxmmmenufore = FXRGB( 40,  0,  0);
  		theme_fxmmmenuback = FXRGB(200,100,100);
  		theme_fxmmselfore  = FXRGB( 40,  0,  0);
  		theme_fxmmselback  = FXRGB(180,100,100);
  		theme_fxmmtipfore  = FXRGB( 90, 50, 50);
  		theme_fxmmtipback  = FXRGB(230,180,180);
  		theme_fxmmhilite  = FXRGB(190, 90, 90);
  		theme_fxmmshadow  = FXRGB(100, 40, 40);
	break;
	case ID_SELECT_THEME_PINK:
  		theme="pink";
  		theme_fxmmfore   = FXRGB(140,80,80);
  		theme_fxmmbase   = FXRGB(250,190,190);
  		theme_fxmmborder = FXRGB(120, 80, 80);
  		theme_fxmmback   = FXRGB(250,230,230);
  		theme_fxmmmenufore  = FXRGB( 90, 50, 50);
  		theme_fxmmmenuback  = FXRGB(220,160,160);
  		theme_fxmmselfore   = FXRGB( 90, 50, 50);
  		theme_fxmmselback   = FXRGB(230,180,180);
  		theme_fxmmtipfore  = FXRGB(140,100,100);
  		theme_fxmmtipback  = FXRGB(250,230,230);
  		theme_fxmmhilite  = FXRGB(250,230,230);
  		theme_fxmmshadow  = FXRGB(200,160,160);
	break;
	case ID_SELECT_THEME_SEA:
  		theme="sea";
  		theme_fxmmfore   = FXRGB( 160,160,240);
  		theme_fxmmbase   = FXRGB(30, 30, 130);
  		theme_fxmmborder = FXRGB( 20, 20, 80);
  		theme_fxmmback   = FXRGB(20, 20, 80);
  		theme_fxmmmenufore = FXRGB( 0,  0,  40);
  		theme_fxmmmenuback = FXRGB(100,100,200);
  		theme_fxmmselfore  = FXRGB( 0,  0,  40);
  		theme_fxmmselback  = FXRGB(100,100,180);
  		theme_fxmmtipfore  = FXRGB( 50, 50, 90);
  		theme_fxmmtipback  = FXRGB(160,160,210);
  		theme_fxmmhilite  = FXRGB( 80, 80, 180);
  		theme_fxmmshadow  = FXRGB(20, 20, 80);
	break;
	case ID_SELECT_THEME_BLUE:
  		theme="blue";
  		theme_fxmmfore   = FXRGB(180,180,250 );
  		theme_fxmmbase   = FXRGB( 60, 60, 160);
  		theme_fxmmborder = FXRGB( 20, 20, 80);
  		theme_fxmmback   = FXRGB( 40, 40, 120);
  		theme_fxmmmenufore = FXRGB(  0,  0, 40);
  		theme_fxmmmenuback = FXRGB(100,100,200);
  		theme_fxmmselfore  = FXRGB(  0,  0, 40);
  		theme_fxmmselback  = FXRGB(100,100,180);
  		theme_fxmmtipfore  = FXRGB( 50, 50, 90);
  		theme_fxmmtipback  = FXRGB(180,180,230);
  		theme_fxmmhilite  = FXRGB( 90, 90, 190);
  		theme_fxmmshadow  = FXRGB( 40, 40, 100);
	break;
	case ID_SELECT_THEME_SKY:
  		theme="sky";
  		theme_fxmmfore   = FXRGB( 80,80,140);
  		theme_fxmmbase   = FXRGB(190,190,250);
  		theme_fxmmborder = FXRGB( 80, 80,120);
  		theme_fxmmback   = FXRGB(230,230,250);
  		theme_fxmmmenufore  = FXRGB( 50, 50, 90);
  		theme_fxmmmenuback  = FXRGB(160,160,220);
  		theme_fxmmselfore   = FXRGB( 50, 50, 90);
  		theme_fxmmselback   = FXRGB(180,180,230);
  		theme_fxmmtipfore  = FXRGB(100,100,140);
  		theme_fxmmtipback  = FXRGB(230,230,250);
  		theme_fxmmhilite  = FXRGB(230,230,250);
  		theme_fxmmshadow  = FXRGB(160,160,200);
	break;
	case ID_SELECT_THEME_MOON:
  		theme="moon";
  		theme_fxmmfore   = FXRGB(150,150,150);
  		theme_fxmmbase   = FXRGB( 30, 30, 30);
  		theme_fxmmborder = FXRGB(  0,  0,  0);
  		theme_fxmmback   = FXRGB( 10, 10, 10);
  		theme_fxmmmenufore  = FXRGB(150,150,150);
  		theme_fxmmmenuback  = FXRGB( 30, 30, 30);
  		theme_fxmmselfore   = FXRGB(10 ,10 , 10);
  		theme_fxmmselback   = FXRGB(100,100,100);
  		theme_fxmmtipfore  = FXRGB(150,150,150);
  		theme_fxmmtipback  = FXRGB( 20, 20, 20);
  		theme_fxmmhilite  = FXRGB(100,100,100);
  		theme_fxmmshadow  = FXRGB( 10, 10, 10);
	break;
	case ID_SELECT_THEME_CLASSIC:
 		theme="classic";
  		theme_fxmmfore   = FXRGB(  0,  0,  0);
  		theme_fxmmbase   = FXRGB(180,180,180);
  		theme_fxmmborder = FXRGB( 50, 50, 50);
  		theme_fxmmback   = FXRGB(210,210,210);
  		theme_fxmmmenufore  = FXRGB(  0,  0,  0);
  		theme_fxmmmenuback  = FXRGB(130,130,130);
  		theme_fxmmselfore   = FXRGB(  0,  0,  0);
  		theme_fxmmselback   = FXRGB(150,150,150);
  		theme_fxmmtipfore  = FXRGB( 50, 50, 50);
  		theme_fxmmtipback  = FXRGB(210,210,210);
  		theme_fxmmhilite  = FXRGB(200,200,200);
  		theme_fxmmshadow  = FXRGB(110,110,110);
	break;
	case ID_SELECT_THEME_SUN:
  		theme="sun";
  		theme_fxmmfore   = FXRGB(100,100,100);
  		theme_fxmmbase   = FXRGB(230,230,230);
  		theme_fxmmborder = FXRGB( 80, 80, 80);
  		theme_fxmmback   = FXRGB(250,250,250);
  		theme_fxmmmenufore  = FXRGB( 50, 50, 50);
  		theme_fxmmmenuback  = FXRGB(180,180,180);
  		theme_fxmmselfore   = FXRGB( 50, 50, 50);
  		theme_fxmmselback   = FXRGB(220,220,220);
  		theme_fxmmtipfore  = FXRGB(100,100,100);
  		theme_fxmmtipback  = FXRGB(250,250,250);
  		theme_fxmmhilite  = FXRGB(250,250,250);
  		theme_fxmmshadow  = FXRGB(160,160,160);
	break;

	}
    return 1;
}


  // Save Colors in the registry file
void MimeTypeDialog::saveThemeColors(){
  getApp()->reg().writeStringEntry("SETTINGS","theme",theme.text());

  getApp()->reg().writeColorEntry("SETTINGS","fxmmbasecolor",theme_fxmmbase);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmforecolor",theme_fxmmfore);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmbackcolor",theme_fxmmback);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmbordercolor",theme_fxmmborder);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmmenuforecolor",theme_fxmmmenufore);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmmenubackcolor",theme_fxmmmenuback);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmselforecolor",theme_fxmmselfore);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmselbackcolor",theme_fxmmselback);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmtipforecolor",theme_fxmmtipfore);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmtipbackcolor",theme_fxmmtipback);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmhilitecolor",theme_fxmmhilite);
  getApp()->reg().writeColorEntry("SETTINGS","fxmmshadowcolor",theme_fxmmshadow);
}


// Set search path for icons
long MimeTypeDialog::onCmdSelectIconPath(FXObject*,FXSelector,void*){
  FXString path=(iconpath.empty()) ? "/usr/local/share/pixmaps" : iconpath.text();
  FXDirDialog opendialog(this,"Search path for icons?");
  opendialog.setDirectory(path);
  if(opendialog.execute()){
    iconpath=opendialog.getDirectory();
    }
  return 1;
  }


// Set terminal
long MimeTypeDialog::onCmdSelectTerminal(FXObject*,FXSelector,void*){
  FXString term=(terminal.empty()) ? "/usr/bin/xterm" : terminal.text();
  FXFileDialog opendialog(this,"Terminal?");
  if(opendialog.execute()){
    terminal=opendialog.getFilename();
    }
  return 1;
  }


// Set default player
long MimeTypeDialog::onCmdSelectPlayer(FXObject*,FXSelector sel,void*){
    switch(FXSELID(sel)){
	case ID_SELECT_PLAYER_MPLAYER:
  		defaultplayer="mplayer";
	break;
	case ID_SELECT_PLAYER_FFPLAY:
  		defaultplayer="ffplay";
	break;
	case ID_SELECT_PLAYER_FXPLAYER:
  		defaultplayer="fxplayer";
	break;
	}
  return 1;
  }



// Set command to open the file with
long MimeTypeDialog::onCmdSelectCommand(FXObject*,FXSelector,void*){
  FXString path=(fileassociation.command.empty()) ? "/usr/bin/" : fileassociation.command.text();
  FXString search=FXFileDialog::getOpenFilename(this,"Command to open file with?",path,"*");
  if(!search.empty()){
    fileassociation.command=search;
    }
  return 1;
  }


long MimeTypeDialog::onCmdSelectMimeType(FXObject*,FXSelector,void*ptr){
  FXString content=(FXchar*)ptr;
  if(!content.empty() && (mimetypelist->findItem(content)==-1)){
    mimetypelist->appendItem(content);
    mimetypelist->sortItems();
    }
  fileassociation.mimetype=content;
  return 1;
  }


long MimeTypeDialog::onCmdFileAssociation(FXObject*,FXSelector,void*){
  saveFileAssociation();

  FXIcon *newicon;
  FXString iconname;
  FXString association;

  fileassociation.extension=associationlist->getItemText(associationlist->getCurrentItem());
  if(fileassociation.extension.empty()) return 1;

  association=getApp()->reg().readStringEntry("FILETYPES",fileassociation.extension.text());

  // here is the same association order of ControlPanel to be able to import associations 
  fileassociation.command = association.section(";",0);  // the command to open the file with
  fileassociation.type = association.section(";",1);     // the name of the type
  fileassociation.bigname = association.section(";",2);  // the big icon 
  fileassociation.smallname = association.section(";",3); // the small icon 
  fileassociation.mimetype = association.section(";",4); // the content-type [object/format]

  if(!fileassociation.mimetype.empty()){
    FXint no=mimetypelist->findItem(fileassociation.mimetype);
    mimetypelist->setCurrentItem(no);
    }
  else {
    FXint no=mimetypelist->findItem(" ");
    mimetypelist->setCurrentItem(no);
    }

  if(button_bigname->getIcon()){
    newicon=button_bigname->getIcon();
    button_bigname->setIcon(NULL);
    delete newicon;
    }
  newicon=createIconApp(getApp(),fileassociation.bigname,iconpath);
  button_bigname->setIcon(newicon);

  if(button_smallname->getIcon()){
    newicon=button_smallname->getIcon();
    button_smallname->setIcon(NULL);
    delete newicon;
    }
  newicon=createIconApp(getApp(),fileassociation.smallname,iconpath);
  button_smallname->setIcon(newicon);

  return 1;
  }


long MimeTypeDialog::onCmdCreateFileAssociation(FXObject*,FXSelector,void*){
  FXString result;
  if(FXInputDialog::getString(result,this,"New File Association","Please enter fileassociation extension:",NULL)){
    if(result.empty()) return 1;
    if((associationlist->findItem(result))>=0){
      FXMessageBox::question(this,MBOX_OK,"Duplicate Association","The extension given %s already exists.",result.text());
      return 1;
      }

    // Save Old
    saveFileAssociation();

    fileassociation.extension = result;
    fileassociation.type = "";
    fileassociation.command = "";
    fileassociation.mimetype = "";
    fileassociation.bigname = "";
    fileassociation.smallname = "";

    // Save New
    saveFileAssociation();

    FXint no = associationlist->appendItem(fileassociation.extension);
    associationlist->setCurrentItem(no,TRUE);
    associationlist->sortItems();
    associationlist->makeItemVisible(associationlist->getCurrentItem());
    }
  return 1;
  }


long MimeTypeDialog::onCmdDeleteFileAssociation(FXObject*,FXSelector,void*){
  if(fileassociation.extension.empty()) return 1;
  if(FXMessageBox::question(this,MBOX_OK_CANCEL,"Delete Fileassociation?","Are you sure you want to delete\nthe fileassociation for %s",fileassociation.extension.text())==MBOX_CLICKED_OK){
    getApp()->reg().deleteEntry("FILETYPES",fileassociation.extension.text());
    fileassociation.extension="";
    associationlist->removeItem(associationlist->getCurrentItem(),TRUE);
    }
  return 1;
  }


long MimeTypeDialog::onCmdRenameFileAssociation(FXObject*,FXSelector,void*){
  FXint no;
  FXString result=fileassociation.extension;
  if(FXInputDialog::getString(result,this,"Rename File Association","Rename File Association",NULL)){
    if(result==fileassociation.extension) return 1;
    if((no=associationlist->findItem(result))>=0){
      if(FXMessageBox::question(this,MBOX_YES_NO,"Replace Association?","Would you like to replace the existing association?")!=MBOX_CLICKED_YES){
        return 1;
        }
      }

    // Find Extension to rename
    getApp()->reg().deleteEntry("FILETYPES",fileassociation.extension.text());
    fileassociation.extension=result;
    // Save renamed Extension 
    saveFileAssociation();
    if(no>=0){
      FXint olditem = associationlist->getCurrentItem();
      associationlist->setCurrentItem(no,TRUE);
      // Remove old Extension
      associationlist->removeItem(olditem);
      }
    else {
      associationlist->setItemText(associationlist->getCurrentItem(),fileassociation.extension);
      }
    }
  return 1;
  }


long MimeTypeDialog::onCmdSelectIcon(FXObject*,FXSelector sel,void*){
  FXString name;
    switch(FXSELID(sel)){
	case ID_SELECT_ICONBIG_NAME: name=fileassociation.bigname; break;
	case ID_SELECT_ICONSMALL_NAME: name=fileassociation.smallname; break;
    }

    if(!FXStat::exists(name)){ name=FXPath::search(iconpath,name); }

    if(name.empty()){
      if(!iconpath.empty()){ name=iconpath.section(PATHLISTSEP,0)+PATHSEPSTRING; }
      else{ name=FXSystem::getCurrentDirectory(); }
    }

  FXFileDialog opendialog(this,"Select the Icon");
  opendialog.setSelectMode(SELECTFILE_EXISTING);
  opendialog.setFilename(name);
  opendialog.showImages(TRUE);
  if(opendialog.execute()){

	FXString iconroot=opendialog.getFilename();
	//FXString iconname=FXPath::name(iconroot);

	switch(FXSELID(sel)){
		case ID_SELECT_ICONBIG_NAME:
			updateIconApp(getApp(),button_bigname,iconroot);
			//fileassociation.bigname=iconame;
			fileassociation.bigname=iconroot;
		break;
		case ID_SELECT_ICONSMALL_NAME:
			updateIconApp(getApp(),button_smallname,iconroot);
			//fileassociation.smallname=iconname;
			fileassociation.smallname=iconroot;
		break;
	}
    }
  return 1;
  }


long MimeTypeDialog::onCmdSelectFont(FXObject*,FXSelector,void*){
  FXFontDialog fontdlg(this,"Change Body Font",DECOR_BORDER|DECOR_TITLE);
  FXFontDesc fontdesc=fontbutton->getFont()->getFontDesc();
  fontdlg.setFontDesc(fontdesc);
  if(fontdlg.execute()){
    FXFont *oldfont=bodyfont;
    fontdesc=fontdlg.getFontDesc();
    bodyfont=new FXFont(getApp(),fontdesc);
    bodyfont->create();
    fontbutton->setFont(bodyfont);
    delete oldfont;
    }
  return 1;
  }

long MimeTypeDialog::onCmdSelectFont2(FXObject*,FXSelector,void*){
  FXFontDialog fontdlg2(this,"Change Menu Font",DECOR_BORDER|DECOR_TITLE);
  FXFontDesc fontdesc2=fontbutton2->getFont()->getFontDesc();
  fontdlg2.setFontDesc(fontdesc2);
  if(fontdlg2.execute()){
    FXFont *oldfont2=menufont;
    fontdesc2=fontdlg2.getFontDesc();
    menufont=new FXFont(getApp(),fontdesc2);
    menufont->create();
    fontbutton2->setFont(menufont);
    delete oldfont2;
    }
  return 1;
  }


// Close the dialog
long MimeTypeDialog::onCmdCloseDialog(FXObject*,FXSelector,void*){

  FXint result=FXMessageBox::question(this,MBOX_SAVE_CANCEL_DONTSAVE,"Save Changes?","Do you want to save changes to the FXMovieManager Registry?\n\nThen you must restart the application for the changes to take effect.");
  if(result==MBOX_CLICKED_CANCEL){ 
	return 1;
  }
  if(result==MBOX_CLICKED_SAVE){

	saveFileAssociation();
	saveThemeColors();
	saveLanguage();
	// Save Settings
  	getApp()->reg().writeStringEntry("SETTINGS","defaultplayer",defaultplayer.text());
  	getApp()->reg().writeIntEntry("SETTINGS","fxmmwheellines",fxmmwheellines);
	getApp()->reg().writeStringEntry("SETTINGS","mimeiconpath",iconpath.text());
  	getApp()->reg().writeStringEntry("SETTINGS","terminal",terminal.text());
    fontspec=fontbutton->getFont()->getFont();
	getApp()->reg().writeStringEntry("SETTINGS","bodyfont",fontspec.text());
    fontspec2=fontbutton2->getFont()->getFont();
	getApp()->reg().writeStringEntry("SETTINGS","menufont",fontspec2.text());

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
	// Thumbnailer
  	getApp()->reg().writeIntEntry("THUMBNAILER","thumbnailSize",thumbnailSize);
  	getApp()->reg().writeIntEntry("THUMBNAILER","imageQuality",imageQuality);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","filmStripOverlay",filmStripOverlay);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","workaroundIssues",workaroundIssues);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","maintainAspectRatio",maintainAspectRatio);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","smartFrameSelection",smartFrameSelection);
#endif
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailShow",autoThumbnailShow);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailCreate",autoThumbnailCreate);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailUpdate",autoThumbnailUpdate);

 	getApp()->reg().writeIntEntry("THUMBNAILER","imagethumbnailSize",imagethumbnailSize);


  }
  FXWindow::hide();
  return 1;
  }


// Restore default settings and close the dialog
long MimeTypeDialog::onCmdRestoreDefaults(FXObject*,FXSelector,void*){

  FXint result=FXMessageBox::question(this,MBOX_SAVE_CANCEL_DONTSAVE,"Restore Default Settings?","Do you want to restore the defaults to the FXMovieManager Registry?\n\nThen you must restart the application for the changes to take effect.");
  if(result==MBOX_CLICKED_CANCEL){ 
	return 1;
  }
  if(result==MBOX_CLICKED_SAVE){

	// Save File Association
	getApp()->reg().writeStringEntry("FILETYPES","dv",";videoclip;/usr/local/share/pixmaps/mime_dv.gif;/usr/local/share/pixmaps/mime_dv_small.gif;video/dv");
	getApp()->reg().writeStringEntry("FILETYPES","dif",";videoclip;/usr/local/share/pixmaps/mime_dv.gif;/usr/local/share/pixmaps/mime_dv_small.gif;video/dv");
	getApp()->reg().writeStringEntry("FILETYPES","3gp",";videoclip;/usr/local/share/pixmaps/mime_3gp.gif;/usr/local/share/pixmaps/mime_3gp_small.gif;video/3gp");
	getApp()->reg().writeStringEntry("FILETYPES","3gp2",";videoclip;/usr/local/share/pixmaps/mime_3gp.gif;/usr/local/share/pixmaps/mime_3gp_small.gif;video/3gp");
	getApp()->reg().writeStringEntry("FILETYPES","mov",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","qt",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","mp4",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","avi",";videoclip;/usr/local/share/pixmaps/mime_avi.gif;/usr/local/share/pixmaps/mime_avi_small.gif;video/x-msvideo");
	getApp()->reg().writeStringEntry("FILETYPES","flv",";videoclip;/usr/local/share/pixmaps/mime_flv.gif;/usr/local/share/pixmaps/mime_flv_small.gif;video/x-flv");
	getApp()->reg().writeStringEntry("FILETYPES","mpg",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mpe",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mpeg",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","gl",";videoclip;/usr/local/share/pixmaps/mime_gl.gif;/usr/local/share/pixmaps/mime_gl_small.gif;video/gl");
	getApp()->reg().writeStringEntry("FILETYPES","ogv",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","ogm",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","ogg",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","vob",";videoclip;/usr/local/share/pixmaps/mime_vob.gif;/usr/local/share/pixmaps/mime_vob_small.gif;video/vob");
	getApp()->reg().writeStringEntry("FILETYPES","mkv",";videoclip;/usr/local/share/pixmaps/mime_mkv.gif;/usr/local/share/pixmaps/mime_mkv_small.gif;video/matroska");
	getApp()->reg().writeStringEntry("FILETYPES","wmv",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-wmv");
	getApp()->reg().writeStringEntry("FILETYPES","wmx",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-wmx");
	getApp()->reg().writeStringEntry("FILETYPES","asf",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-asf");
	getApp()->reg().writeStringEntry("FILETYPES","asx",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-asf");

	getApp()->reg().writeStringEntry("FILETYPES","mp2",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mp3",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mpga",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mpega",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","mid",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio2_small.gif;audio/midi");
	getApp()->reg().writeStringEntry("FILETYPES","midi",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio2_small.gif;audio/midi");
	getApp()->reg().writeStringEntry("FILETYPES","mod",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/mod");
	getApp()->reg().writeStringEntry("FILETYPES","wav",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-wav");
	getApp()->reg().writeStringEntry("FILETYPES","wma",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-ms-wma");
	getApp()->reg().writeStringEntry("FILETYPES","wax",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-ms-wax");
	getApp()->reg().writeStringEntry("FILETYPES","au",";audio;/usr/local/share/pixmaps/mime_audio4.gif;/usr/local/share/pixmaps/mime_audio4_small.gif;audio/basic");
	getApp()->reg().writeStringEntry("FILETYPES","snd",";audio;/usr/local/share/pixmaps/mime_audio4.gif;/usr/local/share/pixmaps/mime_audio4_small.gif;audio/basic");
	getApp()->reg().writeStringEntry("FILETYPES","ra",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");
	getApp()->reg().writeStringEntry("FILETYPES","ram",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");
	getApp()->reg().writeStringEntry("FILETYPES","rm",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");

	getApp()->reg().writeStringEntry("FILETYPES","bm",";image;/usr/local/share/pixmaps/mime_bmp.gif;/usr/local/share/pixmaps/mime_bmp_small.gif;image/bmp");
	getApp()->reg().writeStringEntry("FILETYPES","bmp",";image;/usr/local/share/pixmaps/mime_bmp.gif;/usr/local/share/pixmaps/mime_bmp_small.gif;image/x-windows-bmp");
	getApp()->reg().writeStringEntry("FILETYPES","png",";image;/usr/local/share/pixmaps/mime_png.gif;/usr/local/share/pixmaps/mime_png_small.gif;image/png");
	getApp()->reg().writeStringEntry("FILETYPES","jpg",";image;/usr/local/share/pixmaps/mime_jpg.gif;/usr/local/share/pixmaps/mime_jpg_small.gif;image/jpeg");
	getApp()->reg().writeStringEntry("FILETYPES","jpeg",";image;/usr/local/share/pixmaps/mime_jpg.gif;/usr/local/share/pixmaps/mime_jpg_small.gif;image/jpeg");
	getApp()->reg().writeStringEntry("FILETYPES","gif",";image;/usr/local/share/pixmaps/mime_gif.gif;/usr/local/share/pixmaps/mime_gif_small.gif;image/gif");
	getApp()->reg().writeStringEntry("FILETYPES","xpm",";image;/usr/local/share/pixmaps/mime_xpm.gif;/usr/local/share/pixmaps/mime_xpm_small.gif;image/x-xpixmap");
	getApp()->reg().writeStringEntry("FILETYPES","tif",";image;/usr/local/share/pixmaps/mime_tiff.gif;/usr/local/share/pixmaps/mime_tiff_small.gif;image/tif");
	getApp()->reg().writeStringEntry("FILETYPES","tiff",";image;/usr/local/share/pixmaps/mime_tiff.gif;/usr/local/share/pixmaps/mime_tiff_small.gif;image/tiff");

	getApp()->reg().writeStringEntry("FILETYPES","xz",";archive;/usr/local/share/pixmaps/mime_archive1.gif;/usr/local/share/pixmaps/mime_archive1_small.gif;application/x-xzip");
	getApp()->reg().writeStringEntry("FILETYPES","tar",";archive;/usr/local/share/pixmaps/mime_archive2.gif;/usr/local/share/pixmaps/mime_archive2_small.gif;application/x-tar");
	getApp()->reg().writeStringEntry("FILETYPES","tgz",";archive;/usr/local/share/pixmaps/mime_archive3.gif;/usr/local/share/pixmaps/mime_archive3_small.gif;application/x-compressed");
	getApp()->reg().writeStringEntry("FILETYPES","gz",";archive;/usr/local/share/pixmaps/mime_archive3.gif;/usr/local/share/pixmaps/mime_archive3_small.gif;application/x-gzip");
	getApp()->reg().writeStringEntry("FILETYPES","bz2",";archive;/usr/local/share/pixmaps/mime_archive4.gif;/usr/local/share/pixmaps/mime_archive4_small.gif;application/x-bzip2");
	getApp()->reg().writeStringEntry("FILETYPES","zip",";archive;/usr/local/share/pixmaps/mime_archive5.gif;/usr/local/share/pixmaps/mime_archive5_small.gif;application/x-zip-compressed");

	getApp()->reg().writeStringEntry("FILETYPES","txt",";text;/usr/local/share/pixmaps/mime_text.gif;/usr/local/share/pixmaps/mime_text_small.gif;text/text");
	getApp()->reg().writeStringEntry("FILETYPES","htm",";htm;/usr/local/share/pixmaps/mime_world1.gif;/usr/local/share/pixmaps/mime_world1_small.gif;text/htm");
	getApp()->reg().writeStringEntry("FILETYPES","html",";html;/usr/local/share/pixmaps/mime_world1.gif;/usr/local/share/pixmaps/mime_world1_small.gif;text/html");
	getApp()->reg().writeStringEntry("FILETYPES","h",";header;/usr/local/share/pixmaps/mime_header.gif;/usr/local/share/pixmaps/mime_header_small.gif;text/x-h");
	getApp()->reg().writeStringEntry("FILETYPES","hh",";header;/usr/local/share/pixmaps/mime_header.gif;/usr/local/share/pixmaps/mime_header_small.gif;text/x-h");
	getApp()->reg().writeStringEntry("FILETYPES","c",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","cc",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","cxx",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","cpp",";source;/usr/local/share/pixmaps/mime_sourceplus.gif;/usr/local/share/pixmaps/mime_sourceplus_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","c++",";source;/usr/local/share/pixmaps/mime_sourceplus.gif;/usr/local/share/pixmaps/mime_sourceplus_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","in",";configure;/usr/local/share/pixmaps/mime_configure_in.gif;/usr/local/share/pixmaps/mime_configure_in_small.gif;text/in");
	getApp()->reg().writeStringEntry("FILETYPES","ac",";configure;/usr/local/share/pixmaps/mime_configure_ac.gif;/usr/local/share/pixmaps/mime_configure_ac_small.gif;text/ac");
	getApp()->reg().writeStringEntry("FILETYPES","am",";configure;/usr/local/share/pixmaps/mime_configure_am.gif;/usr/local/share/pixmaps/mime_configure_am_small.gif;text/am");
	getApp()->reg().writeStringEntry("FILETYPES","php",";configure;/usr/local/share/pixmaps/mime_php.gif;/usr/local/share/pixmaps/mime_php_small.gif;text/x-php");
	getApp()->reg().writeStringEntry("FILETYPES","pl",";configure;/usr/local/share/pixmaps/mime_perl.gif;/usr/local/share/pixmaps/mime_perl_small.gif;text/x-perl");
	getApp()->reg().writeStringEntry("FILETYPES","pm",";configure;/usr/local/share/pixmaps/mime_perl.gif;/usr/local/share/pixmaps/mime_perl_small.gif;text/x-perl");
	getApp()->reg().writeStringEntry("FILETYPES","py",";configure;/usr/local/share/pixmaps/mime_python.gif;/usr/local/share/pixmaps/mime_python_small.gif;text/x-python");

	getApp()->reg().writeStringEntry("FILETYPES","sxw",";word;/usr/local/share/pixmaps/mime_world2.gif;/usr/local/share/pixmaps/mime_world2_small.gif;application/sword");
	getApp()->reg().writeStringEntry("FILETYPES","rtf",";word;/usr/local/share/pixmaps/mime_world5.gif;/usr/local/share/pixmaps/mime_world5_small.gif;application/rtf");
	getApp()->reg().writeStringEntry("FILETYPES","doc",";word;/usr/local/share/pixmaps/mime_world3.gif;/usr/local/share/pixmaps/mime_world3_small.gif;application/msword");
	getApp()->reg().writeStringEntry("FILETYPES","odt",";word;/usr/local/share/pixmaps/mime_world4.gif;/usr/local/share/pixmaps/mime_world4_small.gif;application/ooword");
	getApp()->reg().writeStringEntry("FILETYPES","odp",";presentation;/usr/local/share/pixmaps/mime_graph4.gif;/usr/local/share/pixmaps/mime_graph4_small.gif;application/ooimpress");
	getApp()->reg().writeStringEntry("FILETYPES","ppt",";presentation;/usr/local/share/pixmaps/mime_graph3.gif;/usr/local/share/pixmaps/mime_graph3_small.gif;application/mspowerpoint ");
	getApp()->reg().writeStringEntry("FILETYPES","ods",";spreadsheet;/usr/local/share/pixmaps/mime_calc4.gif;/usr/local/share/pixmaps/mime_calc4_small.gif;application/oocalc");
	getApp()->reg().writeStringEntry("FILETYPES","xls",";spreadsheet;/usr/local/share/pixmaps/mime_calc3.gif;/usr/local/share/pixmaps/mime_calc3_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","cvs",";spreadsheet;/usr/local/share/pixmaps/mime_calc2.gif;/usr/local/share/pixmaps/mime_calc2_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","csv",";spreadsheet;/usr/local/share/pixmaps/mime_calc2.gif;/usr/local/share/pixmaps/mime_calc2_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","odg",";drawing;/usr/local/share/pixmaps/mime_graph1.gif;/usr/local/share/pixmaps/mime_graph1_small.gif;application/oodraw");
	getApp()->reg().writeStringEntry("FILETYPES","odf",";formula;/usr/local/share/pixmaps/mime_calc1.gif;/usr/local/share/pixmaps/mime_calc1_small.gif;application/oomath");
	getApp()->reg().writeStringEntry("FILETYPES","odb",";database;/usr/local/share/pixmaps/mime_data4.gif;/usr/local/share/pixmaps/mime_data4_small.gif;application/oobase");

	getApp()->reg().writeStringEntry("FILETYPES","pls",";playlist;/usr/local/share/pixmaps/mime_list.gif;/usr/local/share/pixmaps/mime_list_small.gif;data/playlist");
	getApp()->reg().writeStringEntry("FILETYPES","pdf",";pdf;/usr/local/share/pixmaps/mime_pdf.gif;/usr/local/share/pixmaps/mime_pdf_small.gif;application/pdf");
	getApp()->reg().writeStringEntry("FILETYPES","ps",";postscript;/usr/local/share/pixmaps/mime_ps.gif;/usr/local/share/pixmaps/mime_ps_small.gif;application/pdf");

	getApp()->reg().writeStringEntry("FILETYPES","iso",";iso;/usr/local/share/pixmaps/mime_iso.gif;/usr/local/share/pixmaps/mime_iso_small.gif;file/iso");
	getApp()->reg().writeStringEntry("FILETYPES","rpm",";rpm;/usr/local/share/pixmaps/mime_rpm.gif;/usr/local/share/pixmaps/mime_rpm_small.gif;file/rpm");
	getApp()->reg().writeStringEntry("FILETYPES","srpm",";srpm;/usr/local/share/pixmaps/mime_srpm.gif;/usr/local/share/pixmaps/mime_srpm_small.gif;file/srpm");
	getApp()->reg().writeStringEntry("FILETYPES","pet",";pet;/usr/local/share/pixmaps/mime_pet.gif;/usr/local/share/pixmaps/mime_pet_small.gif;file/pet");
	getApp()->reg().writeStringEntry("FILETYPES","sfs",";sfs;/usr/local/share/pixmaps/mime_sfs.gif;/usr/local/share/pixmaps/mime_sfs_small.gif;file/sfs");
	getApp()->reg().writeStringEntry("FILETYPES","deb",";deb;/usr/local/share/pixmaps/mime_deb.gif;/usr/local/share/pixmaps/mime_deb_small.gif;file/deb");


	// UPPERCASE
	getApp()->reg().writeStringEntry("FILETYPES","DV",";videoclip;/usr/local/share/pixmaps/mime_dv.gif;/usr/local/share/pixmaps/mime_dv_small.gif;video/dv");
	getApp()->reg().writeStringEntry("FILETYPES","DIF",";videoclip;/usr/local/share/pixmaps/mime_dv.gif;/usr/local/share/pixmaps/mime_dv_small.gif;video/dv");
	getApp()->reg().writeStringEntry("FILETYPES","3GP",";videoclip;/usr/local/share/pixmaps/mime_3gp.gif;/usr/local/share/pixmaps/mime_3gp_small.gif;video/3gp");
	getApp()->reg().writeStringEntry("FILETYPES","3GP2",";videoclip;/usr/local/share/pixmaps/mime_3gp.gif;/usr/local/share/pixmaps/mime_3gp_small.gif;video/3gp");
	getApp()->reg().writeStringEntry("FILETYPES","MOV",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","QT",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","MP4",";videoclip;/usr/local/share/pixmaps/mime_mov.gif;/usr/local/share/pixmaps/mime_mov_small.gif;video/quicktime");
	getApp()->reg().writeStringEntry("FILETYPES","AVI",";videoclip;/usr/local/share/pixmaps/mime_avi.gif;/usr/local/share/pixmaps/mime_avi_small.gif;video/x-msvideo");
	getApp()->reg().writeStringEntry("FILETYPES","FLV",";videoclip;/usr/local/share/pixmaps/mime_flv.gif;/usr/local/share/pixmaps/mime_flv_small.gif;video/x-flv");
	getApp()->reg().writeStringEntry("FILETYPES","MPG",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MPE",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MPEG",";videoclip;/usr/local/share/pixmaps/mime_mpg.gif;/usr/local/share/pixmaps/mime_mpg_small.gif;video/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","GL",";videoclip;/usr/local/share/pixmaps/mime_gl.gif;/usr/local/share/pixmaps/mime_gl_small.gif;video/gl");
	getApp()->reg().writeStringEntry("FILETYPES","OGV",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","OGM",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","OGG",";videoclip;/usr/local/share/pixmaps/mime_ogg.gif;/usr/local/share/pixmaps/mime_ogg_small.gif;video/ogg");
	getApp()->reg().writeStringEntry("FILETYPES","VOB",";videoclip;/usr/local/share/pixmaps/mime_vob.gif;/usr/local/share/pixmaps/mime_vob_small.gif;video/vob");
	getApp()->reg().writeStringEntry("FILETYPES","MKV",";videoclip;/usr/local/share/pixmaps/mime_mkv.gif;/usr/local/share/pixmaps/mime_mkv_small.gif;video/matroska");
	getApp()->reg().writeStringEntry("FILETYPES","WMV",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-wmv");
	getApp()->reg().writeStringEntry("FILETYPES","WMX",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-wmx");
	getApp()->reg().writeStringEntry("FILETYPES","ASF",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-asf");
	getApp()->reg().writeStringEntry("FILETYPES","ASX",";videoclip;/usr/local/share/pixmaps/mime_wmv.gif;/usr/local/share/pixmaps/mime_wmv_small.gif;video/x-ms-asf");

	getApp()->reg().writeStringEntry("FILETYPES","MP2",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MP3",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MPGA",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MPEGA",";audio;/usr/local/share/pixmaps/mime_audio1.gif;/usr/local/share/pixmaps/mime_audio1_small.gif;audio/mpeg");
	getApp()->reg().writeStringEntry("FILETYPES","MID",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio2_small.gif;audio/midi");
	getApp()->reg().writeStringEntry("FILETYPES","MIDI",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio2_small.gif;audio/midi");
	getApp()->reg().writeStringEntry("FILETYPES","MOD",";audio;/usr/local/share/pixmaps/mime_audio2.gif;/usr/local/share/pixmaps/mime_audio2_small.gif;audio/mod");
	getApp()->reg().writeStringEntry("FILETYPES","WAV",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-wav");
	getApp()->reg().writeStringEntry("FILETYPES","WMA",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-ms-wma");
	getApp()->reg().writeStringEntry("FILETYPES","WAX",";audio;/usr/local/share/pixmaps/mime_audio3.gif;/usr/local/share/pixmaps/mime_audio3_small.gif;audio/x-ms-wax");
	getApp()->reg().writeStringEntry("FILETYPES","AU",";audio;/usr/local/share/pixmaps/mime_audio4.gif;/usr/local/share/pixmaps/mime_audio4_small.gif;audio/basic");
	getApp()->reg().writeStringEntry("FILETYPES","SND",";audio;/usr/local/share/pixmaps/mime_audio4.gif;/usr/local/share/pixmaps/mime_audio4_small.gif;audio/basic");
	getApp()->reg().writeStringEntry("FILETYPES","RA",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");
	getApp()->reg().writeStringEntry("FILETYPES","RAM",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");
	getApp()->reg().writeStringEntry("FILETYPES","RM",";audio;/usr/local/share/pixmaps/mime_audio5.gif;/usr/local/share/pixmaps/mime_audio5_small.gif;audio/x-realaudio");

	getApp()->reg().writeStringEntry("FILETYPES","BM",";image;/usr/local/share/pixmaps/mime_bmp.gif;/usr/local/share/pixmaps/mime_bmp_small.gif;image/bm");
	getApp()->reg().writeStringEntry("FILETYPES","BMP",";image;/usr/local/share/pixmaps/mime_bmp.gif;/usr/local/share/pixmaps/mime_bmp_small.gif;image/x-windows-bmp");
	getApp()->reg().writeStringEntry("FILETYPES","PNG",";image;/usr/local/share/pixmaps/mime_png.gif;/usr/local/share/pixmaps/mime_png_small.gif;image/png");
	getApp()->reg().writeStringEntry("FILETYPES","JPG",";image;/usr/local/share/pixmaps/mime_jpg.gif;/usr/local/share/pixmaps/mime_jpg_small.gif;image/jpeg");
	getApp()->reg().writeStringEntry("FILETYPES","JPEG",";image;/usr/local/share/pixmaps/mime_jpg.gif;/usr/local/share/pixmaps/mime_jpg_small.gif;image/jpeg");
	getApp()->reg().writeStringEntry("FILETYPES","GIF",";image;/usr/local/share/pixmaps/mime_gif.gif;/usr/local/share/pixmaps/mime_gif_small.gif;image/gif");
	getApp()->reg().writeStringEntry("FILETYPES","XPM",";image;/usr/local/share/pixmaps/mime_xpm.gif;/usr/local/share/pixmaps/mime_xpm_small.gif;image/xpm");
	getApp()->reg().writeStringEntry("FILETYPES","TIF",";image;/usr/local/share/pixmaps/mime_tiff.gif;/usr/local/share/pixmaps/mime_tiff_small.gif;image/tif");
	getApp()->reg().writeStringEntry("FILETYPES","TIFF",";image;/usr/local/share/pixmaps/mime_tiff.gif;/usr/local/share/pixmaps/mime_tiff_small.gif;image/tiff");

	getApp()->reg().writeStringEntry("FILETYPES","XZ",";archive;/usr/local/share/pixmaps/mime_archive1.gif;/usr/local/share/pixmaps/mime_archive1_small.gif;application/x-xzip");
	getApp()->reg().writeStringEntry("FILETYPES","TAR",";archive;/usr/local/share/pixmaps/mime_archive2.gif;/usr/local/share/pixmaps/mime_archive2_small.gif;application/x-tar");
	getApp()->reg().writeStringEntry("FILETYPES","TGZ",";archive;/usr/local/share/pixmaps/mime_archive3.gif;/usr/local/share/pixmaps/mime_archive3_small.gif;application/x-compressed");
	getApp()->reg().writeStringEntry("FILETYPES","GZ",";archive;/usr/local/share/pixmaps/mime_archive3.gif;/usr/local/share/pixmaps/mime_archive3_small.gif;application/x-gzip");
	getApp()->reg().writeStringEntry("FILETYPES","BZ2",";archive;/usr/local/share/pixmaps/mime_archive4.gif;/usr/local/share/pixmaps/mime_archive4_small.gif;application/x-bzip2");
	getApp()->reg().writeStringEntry("FILETYPES","ZIP",";archive;/usr/local/share/pixmaps/mime_archive5.gif;/usr/local/share/pixmaps/mime_archive5_small.gif;application/x-zip-compressed");

	getApp()->reg().writeStringEntry("FILETYPES","TXT",";text;/usr/local/share/pixmaps/mime_text.gif;/usr/local/share/pixmaps/mime_text_small.gif;text/text");
	getApp()->reg().writeStringEntry("FILETYPES","HTM",";htm;/usr/local/share/pixmaps/mime_world1.gif;/usr/local/share/pixmaps/mime_world1_small.gif;text/htm");
	getApp()->reg().writeStringEntry("FILETYPES","HTML",";html;/usr/local/share/pixmaps/mime_world1.gif;/usr/local/share/pixmaps/mime_world1_small.gif;text/html");
	getApp()->reg().writeStringEntry("FILETYPES","H",";header;/usr/local/share/pixmaps/mime_header.gif;/usr/local/share/pixmaps/mime_header_small.gif;text/x-h");
	getApp()->reg().writeStringEntry("FILETYPES","HH",";header;/usr/local/share/pixmaps/mime_header.gif;/usr/local/share/pixmaps/mime_header_small.gif;text/x-h");
	getApp()->reg().writeStringEntry("FILETYPES","C",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","CC",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","CXX",";source;/usr/local/share/pixmaps/mime_source.gif;/usr/local/share/pixmaps/mime_source_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","CPP",";source;/usr/local/share/pixmaps/mime_sourceplus.gif;/usr/local/share/pixmaps/mime_sourceplus_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","C++",";source;/usr/local/share/pixmaps/mime_sourceplus.gif;/usr/local/share/pixmaps/mime_sourceplus_small.gif;text/x-c");
	getApp()->reg().writeStringEntry("FILETYPES","IN",";configure;/usr/local/share/pixmaps/mime_configure_in.gif;/usr/local/share/pixmaps/mime_configure_in_small.gif;text/in");
	getApp()->reg().writeStringEntry("FILETYPES","AC",";configure;/usr/local/share/pixmaps/mime_configure_ac.gif;/usr/local/share/pixmaps/mime_configure_ac_small.gif;text/ac");
	getApp()->reg().writeStringEntry("FILETYPES","AM",";configure;/usr/local/share/pixmaps/mime_configure_am.gif;/usr/local/share/pixmaps/mime_configure_am_small.gif;text/am");
	getApp()->reg().writeStringEntry("FILETYPES","PHP",";configure;/usr/local/share/pixmaps/mime_php.gif;/usr/local/share/pixmaps/mime_php_small.gif;text/x-php");
	getApp()->reg().writeStringEntry("FILETYPES","PL",";configure;/usr/local/share/pixmaps/mime_perl.gif;/usr/local/share/pixmaps/mime_perl_small.gif;text/x-perl");
	getApp()->reg().writeStringEntry("FILETYPES","PM",";configure;/usr/local/share/pixmaps/mime_perl.gif;/usr/local/share/pixmaps/mime_perl_small.gif;text/x-perl");
	getApp()->reg().writeStringEntry("FILETYPES","PY",";configure;/usr/local/share/pixmaps/mime_python.gif;/usr/local/share/pixmaps/mime_python_small.gif;text/x-python");

	getApp()->reg().writeStringEntry("FILETYPES","SXW",";word;/usr/local/share/pixmaps/mime_world2.gif;/usr/local/share/pixmaps/mime_world2_small.gif;application/sword");
	getApp()->reg().writeStringEntry("FILETYPES","RTF",";word;/usr/local/share/pixmaps/mime_world5.gif;/usr/local/share/pixmaps/mime_world5_small.gif;application/rtf");
	getApp()->reg().writeStringEntry("FILETYPES","DOC",";word;/usr/local/share/pixmaps/mime_world3.gif;/usr/local/share/pixmaps/mime_world3_small.gif;application/msword");
	getApp()->reg().writeStringEntry("FILETYPES","ODT",";word;/usr/local/share/pixmaps/mime_world4.gif;/usr/local/share/pixmaps/mime_world4_small.gif;application/ooword");
	getApp()->reg().writeStringEntry("FILETYPES","ODP",";presentation;/usr/local/share/pixmaps/mime_graph4.gif;/usr/local/share/pixmaps/mime_graph4_small.gif;application/ooimpress");
	getApp()->reg().writeStringEntry("FILETYPES","PPT",";presentation;/usr/local/share/pixmaps/mime_graph3.gif;/usr/local/share/pixmaps/mime_graph3_small.gif;application/mspowerpoint ");
	getApp()->reg().writeStringEntry("FILETYPES","ODS",";spreadsheet;/usr/local/share/pixmaps/mime_calc4.gif;/usr/local/share/pixmaps/mime_calc4_small.gif;application/oocalc");
	getApp()->reg().writeStringEntry("FILETYPES","XLS",";spreadsheet;/usr/local/share/pixmaps/mime_calc3.gif;/usr/local/share/pixmaps/mime_calc3_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","CVS",";spreadsheet;/usr/local/share/pixmaps/mime_calc2.gif;/usr/local/share/pixmaps/mime_calc2_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","CSV",";spreadsheet;/usr/local/share/pixmaps/mime_calc2.gif;/usr/local/share/pixmaps/mime_calc2_small.gif;application/msexcel ");
	getApp()->reg().writeStringEntry("FILETYPES","ODG",";drawing;/usr/local/share/pixmaps/mime_graph1.gif;/usr/local/share/pixmaps/mime_graph1_small.gif;application/oodraw");
	getApp()->reg().writeStringEntry("FILETYPES","ODF",";formula;/usr/local/share/pixmaps/mime_calc1.gif;/usr/local/share/pixmaps/mime_calc1_small.gif;application/oomath");
	getApp()->reg().writeStringEntry("FILETYPES","ODB",";database;/usr/local/share/pixmaps/mime_data4.gif;/usr/local/share/pixmaps/mime_data4_small.gif;application/oobase");

	getApp()->reg().writeStringEntry("FILETYPES","PLS",";playlist;/usr/local/share/pixmaps/mime_list.gif;/usr/local/share/pixmaps/mime_list_small.gif;data/playlist");
	getApp()->reg().writeStringEntry("FILETYPES","PDF",";pdf;/usr/local/share/pixmaps/mime_pdf.gif;/usr/local/share/pixmaps/mime_pdf_small.gif;application/pdf");
	getApp()->reg().writeStringEntry("FILETYPES","PS",";postscript;/usr/local/share/pixmaps/mime_ps.gif;/usr/local/share/pixmaps/mime_ps_small.gif;application/pdf");

	getApp()->reg().writeStringEntry("FILETYPES","ISO",";iso;/usr/local/share/pixmaps/mime_iso.gif;/usr/local/share/pixmaps/mime_iso_small.gif;file/iso");
	getApp()->reg().writeStringEntry("FILETYPES","RPM",";rpm;/usr/local/share/pixmaps/mime_rpm.gif;/usr/local/share/pixmaps/mime_rpm_small.gif;file/rpm");
	getApp()->reg().writeStringEntry("FILETYPES","SRPM",";srpm;/usr/local/share/pixmaps/mime_srpm.gif;/usr/local/share/pixmaps/mime_srpm_small.gif;file/srpm");
	getApp()->reg().writeStringEntry("FILETYPES","PET",";pet;/usr/local/share/pixmaps/mime_pet.gif;/usr/local/share/pixmaps/mime_pet_small.gif;file/pet");
	getApp()->reg().writeStringEntry("FILETYPES","SFS",";sfs;/usr/local/share/pixmaps/mime_sfs.gif;/usr/local/share/pixmaps/mime_sfs_small.gif;file/sfs");
	getApp()->reg().writeStringEntry("FILETYPES","DEB",";deb;/usr/local/share/pixmaps/mime_deb.gif;/usr/local/share/pixmaps/mime_deb_small.gif;file/deb");

	language="en";
	quitbuttontext = "\tQuit\tQuit the application";
	openbuttontext = "\tAdd movies\tAdd movies to the playlist";
	audiobuttontext1 = "\tMute\tMute";
	audiobuttontext2 = "\tAudio\tAudio";
	dropbuttontext1 = "\tDrop frames\tDrop frames";
	dropbuttontext2 = "\tAll frames\tAll frames";
	stopbuttontext = "\tStop\tStop MPlayer";
	pausebuttontext = "\tPause\tPause MPlayer";
	playbuttontext = "\tPlay\tPlay the selected movies";
	jplaybuttontext = "JPG\tView\tView as slideshow";
	loopbuttontext1 = "\tLoop\tPlay in loop";
	loopbuttontext2 = "\tOnce\tPlay once";
	zoombuttontext1 = "\tZoom\tZoom video size";
	zoombuttontext2 = "\t1:1\tReal video size";
	hidebuttontext1 = "\tHide\tHide playlist";
	hidebuttontext2 = "\tShow\tShow playlist";
	sizebuttontext = "\tSize\tVideo size";
	outputbuttontext = "\tOutput\tVideo output";
	confbuttontext = "\tConfiguration\tFxMovieManager Configuration";
	upbuttontext = "\tMove one step up\tMove one step up";
	downbuttontext = "\tMove one step down\tMove one step down";
	slistbuttontext = "|_|\tSave playlist\tSave list of movies";
	olistbuttontext = "||>\tLoad playlist\tLoad list of movies";
  	allbuttontext1 = "\tSelect all movies\tSelect all movies";
	allbuttontext2 = "\tDeselect all movies\tDeselect all movies";
	createbuttontext = "\tCreate thumbnails\tCreate thumbnails";
	recreatebuttontext = "\tRecreate thumbnails\tRecreate thumbnails";
  	widebuttontext1 = "\tWide Screen\tShow Wide Screen Thumbnails";
	widebuttontext2 = "\tNormal Screen\tShow Normal Screen Thumbnails";
	deletebuttontext = "\tDelete thumbnails\tDelete thumbnails";
	clearbuttontext = "\tClear the playlist\tClear the playlist";
	increasebuttontext = "\tIncrease thumbnails size\tIncrease thumbnails size";
	decreasebuttontext = "\tDecrease thumbnails size\tDecrease thumbnails size";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
	imgbuttontext1 = "\tDon't show thumbnail images\tDon't show thumbnail images";
	imgbuttontext2 = "\tShow thumbnail images\tShow thumbnail images";
    file_n="Name";
    file_t="Type";
    file_s="Size";
    file_m="Modified date";
    file_u="User";
    file_g="Group";
    file_a="Permissions";
    file_l="Symlink";
    menu_op="Open";
    menu_ow="Open with";
    menu_pr="File Properties";
    menu_mi="Movie Properties";
    menu_re="Rename";
    menu_mo="Move";
    menu_sy="Symlink";
    menu_cu="Cut";
    menu_co="Copy";
    menu_pa="Paste";
    menu_de="Delete";
    menu_te="Terminal";
    menu_he="Run here";
    menu_vi="Virus scanner";
    menu_ar="Archive opener";
    menu_sh="Show/Hide";
    menu_nd="New directory";
    menu_rd="Rename directory";
    menu_dd="Delete directory";
    menu_rf="Refresh";
    menu_ma="Connect device";
    menu_um="Disconnect device";
    menu_up="Move Up";
    menu_do="Move Down";
    menu_al="Select All";
    menu_da="Delete All";
    menu_ap="Append Item";
    menu_in="Insert Item";
    menu_di="Delete Item";
    menu_ed="Edit Item Text";
	saveLanguage();

	theme="dark";
	theme_fxmmfore   = FXRGB(200,200,200);
	theme_fxmmbase   = FXRGB( 60, 60, 60);
	theme_fxmmborder = FXRGB(  0,  0,  0);
	theme_fxmmback   = FXRGB( 20, 20, 20);
	theme_fxmmmenufore  = FXRGB(200,200,200);
	theme_fxmmmenuback  = FXRGB( 10, 10, 10);
	theme_fxmmselfore   = FXRGB(  0,  0,  0);
	theme_fxmmselback   = FXRGB(100,100,100);
	theme_fxmmtipfore  = FXRGB(200,200,200);
	theme_fxmmtipback  = FXRGB( 20, 20, 20);
	theme_fxmmhilite  = FXRGB(100,100,100);
	theme_fxmmshadow  = FXRGB( 10, 10, 10);
	saveThemeColors();

	// Save Other Settings
  	getApp()->reg().writeStringEntry("SETTINGS","defaultplayer","/usr/bin/mplayer");
  	getApp()->reg().writeIntEntry("SETTINGS","fxmmwheellines",4);
	getApp()->reg().writeStringEntry("SETTINGS","mimeiconpath","/usr/local/share/pixmaps");
  	getApp()->reg().writeStringEntry("SETTINGS","terminal","/usr/bin/xterm");
	getApp()->reg().writeStringEntry("SETTINGS","bodyfont","Fixed [Misc],100,normal,regular");
	getApp()->reg().writeStringEntry("SETTINGS","menufont","Fixed [Misc],100,normal,regular");

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
	// Save Thumbnailer Settings
  	getApp()->reg().writeIntEntry("THUMBNAILER","thumbnailSize",256);
  	getApp()->reg().writeIntEntry("THUMBNAILER","imageQuality",8);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","filmStripOverlay",false);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","workaroundIssues",false);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","maintainAspectRatio",true);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","smartFrameSelection",false);
#endif
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailShow",true);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailCreate",false);
  	getApp()->reg().writeBoolEntry("THUMBNAILER","autoThumbnailUpdate",false);

  	getApp()->reg().writeIntEntry("THUMBNAILER","imagethumbnailSize",128);
  }

  FXWindow::hide();
  return 1;
  }

long MimeTypeDialog::onCmdCustomLanguage(FXObject*,FXSelector,void*){
    languagedialog->show(PLACEMENT_OWNER);
  return 1;
  }


// EOF
